% Entry point (Hit F5 to run)
%{
===============================================================================
DESIGNED BY:    Tsezar F. Seman
AFFILIATION:    NJIT University, Physics Department
MODIFIED ON:    04/10/2012
COPYRIGHT:      (c) Tsezar F. Seman. All rights reserved.
PURPOSE:        Plotting various RIXS data.
===============================================================================
%}
function merged_I()
	clc; addpath('../../_common_');
	clear all;
	N = 16;		% must be divisible by 4
	%--------------------------------------------
	% GENERATE RIXS DATASET:
	CmdTitle(sprintf('LaSrMnO4 PLOTTING RIXS: N = %i', N));
	fprintf('## LOADING CALCULATED RIXS: ... \n');
	LoadCalcRixs(N);
	%--------------------------------------------
	% PLOTTING:
	fprintf('\n## GENERATING PLOTS: ... \n');

	gammaW = 0.6;	
%	Plot_qwContourSmooth(gammaW);

	dCase = 1; % {1-red,2-blue,3-black}
	Plot_Merged(dCase);	
	switch dCase
		case 1
			fig2eps(gcf,'merged_red');
		case 2
			fig2eps(gcf,'merged_blue');
		case 3
			fig2eps(gcf,'merged_black');
	end
	
	
end

%==========================================================
% LINE/POINT PLOTTING:
function index = KPtsToIndex(kPts)
	global GL
	
	del = 1e-10;
	index = zeros(size(kPts,1),1);
	for i = 1:size(GL.kPoints,1)
		k = GL.kPoints(i,:);
		tmp = kPts;
		tmp(:,1) = tmp(:,1) - k(1);
		tmp(:,2) = tmp(:,2) - k(2);
		index(sum(abs(tmp),2) < del, 1) = i;
	end
end
function index = KPtsToIndexExt(kPts)
	global GL
	
	del = 1e-10;
	index = zeros(size(kPts,1),1);
	for i = 1:size(GL.kPointsExt,1)
		k = GL.kPointsExt(i,:);
		tmp = kPts;
		tmp(:,1) = tmp(:,1) - k(1);
		tmp(:,2) = tmp(:,2) - k(2);
		index(sum(abs(tmp),2) < del, 1) = GL.kIndexExt(i,1);
	end
end

function Plot_qwContourSmooth(gammaW)
	global GL
	
	% kVals cols: 1 - parametric x value, 2 - vertical line flag, 3:4 - actual k-value
	sq = sqrt(2);
	p2 = pi/2;
	p4 = pi/4;
	p8 = pi/8;
	switch GL.N
		case 8
			% diagonal line
			kVals = [ ...
				[-pi*sq,		1,		-pi, -pi]; ...
				[-3*p4*sq,		0,		-3*pi/4, -3*pi/4]; ...
				[-p2*sq,		1,		-pi/2, -pi/2]; ...
				[-p4*sq,		0,		-pi/4, -pi/4]; ...
				[0,				1,		0, 0]; ...
				[p4*sq,			0,		pi/4, pi/4]; ...
				[p2*sq,			1,		pi/2, pi/2]; ...
				[3*p4*sq,		0,		3*pi/4, 3*pi/4]; ...
				[pi*sq,			1,		pi, pi] ];
			PlotRixsContribSmoothQW_Fig(kVals,gammaW);
		case 16
			% diagonal line
			kVals = [ ...
				[-sq*8*p8,		1,		-8*p8, -8*p8]; ...
				[-sq*7*p8,		0,		-7*p8, -7*p8]; ...
				[-sq*6*p8,		0,		-6*p8, -6*p8]; ...
				[-sq*5*p8,		0,		-5*p8, -5*p8]; ...
				[-sq*4*p8,		1,		-4*p8, -4*p8]; ...
				[-sq*3*p8,		0,		-3*p8, -3*p8]; ...
				[-sq*2*p8,		0,		-2*p8, -2*p8]; ...
				[-sq*1*p8,		0,		-1*p8, -1*p8]; ...
				[0, 			1,		0, 0]; ...
				[sq*1*p8,		0,		1*p8, 1*p8]; ...
				[sq*2*p8,		0,		2*p8, 2*p8]; ...
				[sq*3*p8,		0,		3*p8, 3*p8]; ...
				[sq*4*p8,		1,		4*p8, 4*p8]; ...
				[sq*5*p8,		0,		5*p8, 5*p8]; ...
				[sq*6*p8,		0,		6*p8, 6*p8]; ...
				[sq*7*p8,		0,		7*p8, 7*p8]; ...
				[sq*8*p8,		1,		8*p8, 8*p8] ];
			PlotRixsContribSmoothQW_Fig(kVals,gammaW);
	end
end
function PlotRixsContribSmoothQW_Fig(kVals,gammaW)
	global GL
	
	Ny = 200;
	Nx = 200;
	
	LorentzianW = @(ww,w0) ( (gammaW./pi) ./ ((ww-w0).^2 + gammaW.^2) );
	
	nk = size(kVals,1);	
	minmax_q = [kVals(1,1), kVals(nk,1)];
	%minmax_w = [floor( min(GL.RIXS(:,4)) ), ceil( max(GL.RIXS(:,4)) )];
	minmax_w = [0, ceil( max(GL.RIXS(:,4)) )];
	xCont = linspace(minmax_q(1), minmax_q(2), Nx);
	yCont = linspace(minmax_w(1), minmax_w(2), Ny);
	
	% k-point indexes to use in search for RIXS values
	kInd = KPtsToIndex(kVals(:,3:4)) + KPtsToIndexExt(kVals(:,3:4));
	
	% collect all w-sets as smooth Lorentzians
	w_set = zeros(Ny, nk);
	for ik = 1:nk
		% collect all intensities and energies for a given k-point
		IWrixs = GL.RIXS(GL.RIXS(:,8) == kInd(ik), 3:4);
		I_tmp = zeros(size(yCont));
		for iw = 1:size(IWrixs,1)
			I_tmp = I_tmp + IWrixs(iw,1) .* LorentzianW(yCont,IWrixs(iw,2));
		end
		w_set(:,ik) = I_tmp';
	end
	
% save data for further analysis
wVals = yCont;
qVals = kVals(:,1);
save('data_theor.mat', 'w_set','wVals','qVals');
	
	% interpolate horizontally
	[qq,ww] = meshgrid(xCont, yCont);
	zz = zeros(size(qq));
	q_param = kVals(:,1)';
	
%dq = abs(q_param(2) - q_param(1))/2;
%q_param = [q_param(1)-dq, q_param, q_param(nk)+dq];
%w_set = [w_set(:,1), w_set, w_set(:,nk)];
%n_extend = 2;
%n_extend = 0;

	for iw = 1:Ny
		I_tmp = w_set(iw,:);
%		p = polyfit(q_param, I_tmp, nk-1 + n_extend);
%		zz(iw,:) = polyval(p, xCont);
		
		zz(iw,:) = spline(q_param,I_tmp, xCont);
	end
	maxZ = max(max(zz));
	zz = zz ./ maxZ;

	% plot contour map
	szTitle = sprintf('%s: Integrated I_{ RIXS} Contribution',GL.figPref);
	GL.figId = FigId(GL.figId,szTitle);
	pcolor(qq,ww,zz);
	caxis([0, 1]);
	axis('tight');	%'equal'
	colormap(hot(128));
	shading('flat');
	%colorbar('Position',[0.92,0.7,0.015,0.2]); % , 'XColor',[.9 .9 .9],'YColor',[.9 .9 .9]
	colorbar

	% Gamma text
	hold on;
	clrText = [1 .8 0];
	text(kVals(1,1)+0.2,minmax_w(2)-.05, sprintf('\\gamma_{\\omega} = %g',gammaW ), ...
		'Color',clrText, 'HorizontalAlignment','left', 'VerticalAlignment','top');
	
	% axis matters
	title(szTitle);
	h = xlabel('Parameterized \Delta{q}');
	ylabel('Energy change \Delta{\omega} (eV)');
	set(gca, 'TickDir','out');
	
	% better x-axis
	x_Tick = kVals(:,1)';
	clrBlk = [0 0 0];
	for i = 1:nk
		if kVals(i,2) == 1
			sLabel = sprintf('(%s,%s)', Num2Latex(kVals(i,3),1), Num2Latex(kVals(i,4),1) );
			text(kVals(i,1),minmax_w(1)-0.08, sLabel, 'FontSize',9, 'Color',clrBlk,...
				'HorizontalAlignment','center', 'VerticalAlignment','top');
		end
	end
	
ylim([0,5])
	
	set(gca,'XTick',x_Tick, 'XTickLabel','');
	% shift down the xlabel
	pos = get(h,'Position');
	pos = pos .* [1 1.5 1];
	set(h,'Position',pos);
	
	hold off;
	axis('square');
end


function [expr_w,expr_I,expr_q] = LoadExp(dCase)
	switch dCase
		case 1
			data = load('data_red.txt');
			expr_w = data(:,1);
			expr_I = data(:, 2:size(data,2));
			expr_q = load('data_red_H.txt');
		case 2
			data = load('data_blu.txt');
			expr_w = data(:,1);
			expr_I = data(:, 2:size(data,2));
			expr_q = load('data_blu_H.txt');
		case 3
			data = load('data_blk.txt');
			expr_w = data(:,1);
			expr_I = data(:, 2:size(data,2));
			expr_q = load('data_blk_H.txt');
	end

end
function Plot_Merged(dCase)
	global GL
	
%{
	% CASE 0:
	scale_I = 51000;
	% background params:
	A = 3200;
	gamma_bk = 2.5;
	x0 = 5.0;
%}
%{-
	% CASE 1:  (best)
	scale_I = 65000;
	% background params:
	A = 1600;
	gamma_bk = 1.5;
	x0 = 4.5;
%}
%{
	% CASE 2:
	scale_I = 65000;
	% background params:
	A = 1300;
	gamma_bk = 1.5;
	x0 = 4.0;
%}
	
	GL.figId = FigId(GL.figId,'');
	FontSize = 18;
	
	% load experimental data:
	[expr_w,expr_I,expr_q] = LoadExp(dCase);
	nqExpr = size(expr_q,2);
	
	% vars: w_set, qVals, wVals
	load('data_theor.mat');
	w_set = scale_I*w_set;  %  + shift_I
	
	% q-point
	nq = size(qVals,1);
	hold on;
	
	
	% plot Lorenztian background
	LorentzianX = @(xx,x0) A*( (gamma_bk./pi) ./ ((xx-x0).^2 + gamma_bk.^2) );
	yShift = ( LorentzianX(wVals,x0) )';
	plot(wVals,yShift, '--k')

	lab = ((0:pi/8:pi) * 0.5 / pi)';

	dyM = 80;
	
	% plot theoretical data:
	clr = linspace(0.8, 0, ceil(nq/2))';
	clr = [clr, clr, clr];
	xM = 3.3;
	yM = 1500 - ceil(nq/2)*dyM;
	for iq = 1:ceil(nq/2)
		lw = 2 + 2*mod(iq,2);
		% theory line
		plot(wVals, w_set(:,iq+ceil(nq/2)-1) + yShift, 'LineWidth',lw, 'Color',clr(iq,:));
		% theory label
		plot([xM,xM+0.3],[yM,yM], '-', 'LineWidth',lw, 'Color',clr(iq,:))
		text(xM+0.35, yM, sprintf('%.2f', lab(iq)), 'FontSize',FontSize);
		yM = yM + dyM;
	end
	text(xM+0.35, yM, sprintf('H_{th}:'), 'FontSize',FontSize);

	% plot experimental data:
	clr = jet(101+8);
	xM = 4.1;
	yM = 1500 - nqExpr*dyM;
	lw = 2.5;
	for iq = 1:nqExpr
		% color index
		iclr = round(100*expr_q(iq));
		iclr = min(max(iclr,-50), 58) + 51;
		% experimental line
		plot(expr_w, expr_I(:,iq), 'o-', 'LineWidth',lw, 'Color',clr(iclr,:), ...
			'MarkerFaceColor',clr(iclr,:));
		% experimental label
		plot([xM,xM+0.3],[yM,yM], '-', 'LineWidth',lw, 'Color',clr(iclr,:));
		plot(xM+0.3/2,yM, 'o', 'LineWidth',lw, 'Color',clr(iclr,:), ...
			'MarkerFaceColor',clr(iclr,:));
		text(xM+0.8, yM, sprintf('% .2f', expr_q(iq)), 'FontSize',FontSize, ...
			'HorizontalAlignment','right');
		yM = yM + dyM;
	end
	text(xM+0.35, yM, sprintf('H_{ex}:'), 'FontSize',FontSize);
	
	switch dCase
		case 1
			text(0.1, 1500, sprintf('(a)'), 'FontSize',24);
		case 2
			text(0.1, 1500, sprintf('(b)'), 'FontSize',24);
		case 3
			text(0.1, 1500, sprintf('(c)'), 'FontSize',24);
	end
	
	hold off;
	
	% Axis Matters:
	xlim([0,5]);
	ylim([0,1600]);
	box on;
	
%	title(sprintf('Lorenzian \\gamma = %.2f, (Backbround: x_0 = %.2f eV, \\gamma_{bk} = %.2f, A = %g, scale = %g)', ...
%		gammaW,x0,gamma_bk,A,scale_I));

	set(gca, 'XTick',0:5);
	set(gca, 'YTick',0:400:1600);
	set(get(gca,'XLabel'),'String','Energy (eV)', 'FontSize',FontSize);
	set(get(gca,'YLabel'),'String','RIXS Intensity', 'FontSize',FontSize);
	set(gca, 'FontSize',FontSize, 'LineWidth',2);
	set(gca,'PlotBoxAspectRatio',[1 .8 1]);
end
%==========================================================
% SAVING/LOADING:
function LoadCalcRixs(N)
	% ACCESS to overwrite
	global GL

	load(sprintf('N%02i_CalcRixs.mat',N));
	
	GL.figId = 131;
	GL.figPref = sprintf('N = %d',GL.N);
end
%==========================================================







































