% Entry point (Hit F5 to run)
%{
===============================================================================
DESIGNED BY:    Tsezar F. Seman
AFFILIATION:    NJIT University, Physics Department
MODIFIED ON:    04/10/2012
COPYRIGHT:      (c) Tsezar F. Seman. All rights reserved.
PURPOSE:        Plotting various RIXS data.
===============================================================================
%}
function plot_red_vertical()
	clc; addpath('../../_common_');
	clear all;
	N = 16;
	isSaveEPS = 1;
	%--------------------------------------------
	% GENERATE RIXS DATASET:
	CmdTitle(sprintf('LaSrMnO4 PLOTTING RIXS: N = %i', N));
	fprintf('## LOADING CALCULATED RIXS: ... \n');
	LoadCalcRixs(N);
	%--------------------------------------------
	% PLOTTING:
	fprintf('\n## GENERATING PLOTS: ... \n');

	gammaW = 0.6;

	Plot_ExperRed(gammaW);
	if isSaveEPS; fig2eps(gcf,'fig2_a'); end;
	
	Plot_qwContourSmooth(gammaW);
	if isSaveEPS; fig2eps(gcf,'fig2_b'); end;
	
end

%==========================================================
% LINE/POINT PLOTTING:
function index = KPtsToIndex(kPts)
	global GL
	
	del = 1e-10;
	index = zeros(size(kPts,1),1);
	for i = 1:size(GL.kPoints,1)
		k = GL.kPoints(i,:);
		tmp = kPts;
		tmp(:,1) = tmp(:,1) - k(1);
		tmp(:,2) = tmp(:,2) - k(2);
		index(sum(abs(tmp),2) < del, 1) = i;
	end
end
function index = KPtsToIndexExt(kPts)
	global GL
	
	del = 1e-10;
	index = zeros(size(kPts,1),1);
	for i = 1:size(GL.kPointsExt,1)
		k = GL.kPointsExt(i,:);
		tmp = kPts;
		tmp(:,1) = tmp(:,1) - k(1);
		tmp(:,2) = tmp(:,2) - k(2);
		index(sum(abs(tmp),2) < del, 1) = GL.kIndexExt(i,1);
	end
end

function Plot_qwContourSmooth(gammaW)
	global GL
	
	% kVals cols: 1 - parametric x value, 2 - vertical line flag, 3:4 - actual k-value
	sq = sqrt(2);
	p2 = pi/2;
	p4 = pi/4;
	p8 = pi/8;
	switch GL.N
		case 8
			% diagonal line
			kVals = [ ...
				[-pi*sq,		1,		-pi, -pi]; ...
				[-3*p4*sq,		0,		-3*pi/4, -3*pi/4]; ...
				[-p2*sq,		1,		-pi/2, -pi/2]; ...
				[-p4*sq,		0,		-pi/4, -pi/4]; ...
				[0,				1,		0, 0]; ...
				[p4*sq,			0,		pi/4, pi/4]; ...
				[p2*sq,			1,		pi/2, pi/2]; ...
				[3*p4*sq,		0,		3*pi/4, 3*pi/4]; ...
				[pi*sq,			1,		pi, pi] ];
			PlotRixsContribSmoothQW_Fig(kVals,gammaW);
		case 16
			% diagonal line
			kVals = [ ...
				[-sq*8*p8,		1,		-8*p8, -8*p8]; ...
				[-sq*7*p8,		0,		-7*p8, -7*p8]; ...
				[-sq*6*p8,		0,		-6*p8, -6*p8]; ...
				[-sq*5*p8,		0,		-5*p8, -5*p8]; ...
				[-sq*4*p8,		1,		-4*p8, -4*p8]; ...
				[-sq*3*p8,		0,		-3*p8, -3*p8]; ...
				[-sq*2*p8,		0,		-2*p8, -2*p8]; ...
				[-sq*1*p8,		0,		-1*p8, -1*p8]; ...
				[0, 			1,		0, 0]; ...
				[sq*1*p8,		0,		1*p8, 1*p8]; ...
				[sq*2*p8,		0,		2*p8, 2*p8]; ...
				[sq*3*p8,		0,		3*p8, 3*p8]; ...
				[sq*4*p8,		1,		4*p8, 4*p8]; ...
				[sq*5*p8,		0,		5*p8, 5*p8]; ...
				[sq*6*p8,		0,		6*p8, 6*p8]; ...
				[sq*7*p8,		0,		7*p8, 7*p8]; ...
				[sq*8*p8,		1,		8*p8, 8*p8] ];
			PlotRixsContribSmoothQW_Fig(kVals,gammaW);
	end
end
function PlotRixsContribSmoothQW_Fig(kVals,gammaW)
	global GL
	
	Ny = 200;
	Nx = 200;
	
	LorentzianW = @(ww,w0) ( (gammaW./pi) ./ ((ww-w0).^2 + gammaW.^2) );
	
	nk = size(kVals,1);	
	minmax_q = [kVals(1,1), kVals(nk,1)];
	%minmax_w = [floor( min(GL.RIXS(:,4)) ), ceil( max(GL.RIXS(:,4)) )];
	minmax_w = [0, ceil( max(GL.RIXS(:,4)) )];
	xCont = linspace(minmax_q(1), minmax_q(2), Nx);
	yCont = linspace(minmax_w(1), minmax_w(2), Ny);
	
	% k-point indexes to use in search for RIXS values
	kInd = KPtsToIndex(kVals(:,3:4)) + KPtsToIndexExt(kVals(:,3:4));
	
	% collect all w-sets as smooth Lorentzians
	w_set = zeros(Ny, nk);
	for ik = 1:nk
		% collect all intensities and energies for a given k-point
		IWrixs = GL.RIXS(GL.RIXS(:,8) == kInd(ik), 3:4);
		I_tmp = zeros(size(yCont));
		for iw = 1:size(IWrixs,1)
			I_tmp = I_tmp + IWrixs(iw,1) .* LorentzianW(yCont,IWrixs(iw,2));
		end
		w_set(:,ik) = I_tmp';
	end
	
	% interpolate horizontally
	[qq,ww] = meshgrid(xCont, yCont);
	zz = zeros(size(qq));
	q_param = kVals(:,1)';
	
	for iw = 1:Ny
		I_tmp = w_set(iw,:);
		zz(iw,:) = spline(q_param,I_tmp, xCont);
	end
	maxZ = max(max(zz));
	zz = zz ./ maxZ;

	% plot contour map
	szTitle = sprintf('%s: Integrated I_{ RIXS} Contribution',GL.figPref);
	GL.figId = FigId(GL.figId,szTitle);
	pcolor(qq,ww,zz);
	caxis([0, 1]);
	colormap(hot(128));
	shading('flat');
	%colorbar('Position',[0.92,0.7,0.015,0.2]); % , 'XColor',[.9 .9 .9],'YColor',[.9 .9 .9]
%	colorbar

	% Gamma text
	hold on;
	clrText = [1 .8 0];
	text(kVals(1,1)+0.2,minmax_w(2)-.05, sprintf('\\gamma_{\\omega} = %g',gammaW ), ...
		'Color',clrText, 'HorizontalAlignment','left', 'VerticalAlignment','top');
	hold off;
	
	% axis adjustments:
	FontSize = 20;
	xlabel('H (r.l.u.)', 'FontSize',FontSize);
	
	pipi = sqrt(2)*pi;
	xlim([0, pipi]);
	ylim([0.5, 5]);
	
	x_Tick = [0, pipi/2, pipi];
	set(gca,'XTick',x_Tick, 'XTickLabel',{'0';'0.25';'0.5'});
	set(gca, 'YTick',[], 'YTickLabel','');
	set(gca, 'LineWidth',2, 'FontSize',FontSize);
	set(gca,'PlotBoxAspectRatio',[(4/3/5/.7) 1 1]);
%	set(gca, 'TickDir','out');
end

function Plot_ExperRed(gammaW)
	global GL
		
	GL.figId = FigId(GL.figId,'');
	
	% experimental:
	de_r = load('data_red.txt');
	expr_w = de_r(:,1);
	expr_I = de_r(:, 2:size(de_r,2));
	expr_q = load('data_red_H.txt');
	nqExpr = size(expr_q,2);
	
	hold on;

	% plot experimental data:
	clr = lines(nqExpr);
	clr(1:7,:) = clr([5,1,4,2,6,7,3],:);
	clr(6,:) = [.8 .4 0];
	for iq = 1:nqExpr
		hl(iq) = plot(expr_I(:,iq), expr_w, 'o-', ...
			'LineWidth',2, 'Color',clr(iq,:), 'MarkerFaceColor',clr(iq,:));
		cQexp{iq,1} = sprintf('% .2f',expr_q(iq));
	end
	hold off;
	
	% axis adjustments:
	FontSize = 20;
	
	hleg = legend(hl,cQexp);
%	set(hleg,'Box','off');
	
	xlabel('Intensity', 'FontSize',FontSize);
	ylabel('Energy (eV)', 'FontSize',FontSize);	
	
	xlim([0,1500]);
	ylim([0.5,5]);
	box on;
	set(gca, 'YTick',1:5)
	set(gca, 'LineWidth',2, 'FontSize',FontSize);
	set(gca,'YGrid','on');
	
	set(gca,'PlotBoxAspectRatio',[(1/3/.7) 1 1]);
end
%==========================================================
% SAVING/LOADING:
function LoadCalcRixs(N)
	% ACCESS to overwrite
	global GL

	load(sprintf('N%02i_CalcRixs.mat',N));
	
	GL.figId = 131;
	GL.figPref = sprintf('N = %d',GL.N);
end
%==========================================================







































