function kline_merged_PRB()
	% Re-creation of experimental v-shape data plot
	clc; addpath('../../_common_');
	%==================================
%	figId = 71;	N = 8;		% 8 or 16
	figId = 72;	N = 16;		% 8 or 16

	isHalf = 0;
	%dir = 'export_3ev_raw/';
	dir = 'export_3ev_woLorentz/';	
	%==================================
	
	[dexp_k,dexp_b,dexp_r] = GetDataExper(dir);
	dc = GetDataCalc(N);
	
	if isHalf == 1
		[dexp_k_n,dexp_b_n,dexp_r_n] = GetDataExperFlip(dir);
	end
	
	minmaxY = [-0.05, 1.15];	% experimental
	minmaxX = 0.75*[-1,1];
	ticksX = [-0.75,-0.5,-0.25,0,0.25,0.5,0.75];
	lw = 2;				% exper. line weight
	ms = 8;				% exper. marker size
	FontSize = 18;
	figure(figId); clf;
	
	% grid lines
	clrGrid = 0.6*[1,1,1];
	line(-0.5*[1,1],minmaxY, 'Color',clrGrid, 'LineStyle','--', 'LineWidth',1);
	line( 0.5*[1,1],minmaxY, 'Color',clrGrid, 'LineStyle','--', 'LineWidth',1);
	line( minmaxX,[0,0], 'Color',clrGrid, 'LineStyle','--', 'LineWidth',1);
	line( minmaxX,[1,1], 'Color',clrGrid, 'LineStyle','--', 'LineWidth',1);
	
	% define axis
	ax1 = gca;
	
	% number of data sets
	ndc = size(dc,1);
	clrLine = jet(ndc);
%	clrLine = sortrows(clrLine,[1,2,3]);

clrLine(5,:) = clrLine(6,:);
clrLine(6,:) = [1,0,0];

	% plotting theoretical data
	for i = 1:ndc
		hl(i) = line(dc{i,1}(:,1), dc{i,1}(:,2), ...
			'Color',clrLine(i,:), 'LineWidth',2, 'LineStyle','-');	
		cLeg{i} = sprintf('t_0= %g', dc{i,2});
	end

	% plotting experimental data
	hl(ndc+1) = line(dexp_r(:,1),dexp_r(:,2), 'Color','r', 'Marker','d', ...
		'LineStyle','none', 'LineWidth',lw,'MarkerSize',ms, 'MarkerFaceColor','r');
	hl(ndc+2) = line(dexp_b(:,1),dexp_b(:,2), 'Color','b', 'Marker','s', ...
		'LineStyle','none', 'LineWidth',lw,'MarkerSize',ms, 'MarkerFaceColor','b');
	hl(ndc+3) = line(dexp_k(:,1),dexp_k(:,2), 'Color','k', 'Marker','o', ...
		'LineStyle','none', 'LineWidth',lw,'MarkerSize',ms, 'MarkerFaceColor','k');
	cLeg{ndc+1} = '2\theta = 68^o';
	cLeg{ndc+2} = '2\theta = 78^o';
	cLeg{ndc+3} = '\theta = 40^o';
	
	if isHalf == 1
		hl(ndc+1) = line(dexp_r_n(:,1),dexp_r_n(:,2), 'Color','r', 'Marker','d', ...
			'LineStyle','none', 'LineWidth',lw,'MarkerSize',ms, 'MarkerFaceColor','none');
		hl(ndc+2) = line(dexp_b_n(:,1),dexp_b_n(:,2), 'Color','b', 'Marker','s', ...
			'LineStyle','none', 'LineWidth',lw,'MarkerSize',ms, 'MarkerFaceColor','none');
		hl(ndc+3) = line(dexp_k_n(:,1),dexp_k_n(:,2), 'Color','k', 'Marker','o', ...
			'LineStyle','none', 'LineWidth',lw,'MarkerSize',ms, 'MarkerFaceColor','none');
	end
	
	%{
	BiLayer = load('bi-layer.txt');
	hl(ndc+4) = line(BiLayer(:,1),BiLayer(:,2), 'Color',[1,0,0.9], 'Marker','+', ...
			'LineStyle','none', 'LineWidth',lw,'MarkerSize',ms, 'MarkerFaceColor','none');
	cLeg{ndc+4} = 'bi-layer';
	%}
	
	hleg = legend(hl, cLeg);
	set(hleg, 'Location','SouthWest', 'Color','w')
%	box(hleg,'off')

	set(ax1, 'XLim',minmaxX);
	set(ax1, 'YLim',minmaxY);
	set(ax1, 'XTick',ticksX);
	set(ax1, 'YTick',0:0.2:1);
	set(ax1, 'FontSize',FontSize, 'LineWidth',2);
	
	if isHalf == 1
		set(hleg, 'Location','NorthWest', 'Color','w')
		set(ax1, 'XLim',[0,minmaxX(2)]);
	end
	
%	title(sprintf('N=%d: k-Line Collection',N));
	set(get(ax1,'XLabel'),'String','H (r.l.u.)', 'FontSize',FontSize);
	set(get(ax1,'YLabel'),'String','Normalized RIXS intensity', 'FontSize',FontSize);

	set(ax1,'PlotBoxAspectRatio',[1 .8 1])
	box('on')
	
%	camva(ax1,1.2*camva)

	fig2eps(gcf, sprintf('N%02d_k-line.eps',N));
end
	
function [dexp_k,dexp_b,dexp_r] = GetDataExper(dir)
	minY = 4026.6;	% obtained from Excel
	
	% load experimental data:
	dexp_r = load([dir,'data_exp_red.txt']);
	dexp_b = load([dir,'data_exp_blue.txt']);
	dexp_k = load([dir,'data_exp_black.txt']);
	
	% subtract lowest value
%	dexp_r(:,2) = dexp_r(:,2) - minY;
%	dexp_b(:,2) = dexp_b(:,2) - minY;
%	dexp_k(:,2) = dexp_k(:,2) - minY;
	
	% max point based on 2-top-red and 2-top-blue
	maxY = (dexp_r(1,2) + dexp_r(7,2) + dexp_b(1,2) + dexp_b(5,2)) / 4;

	dexp_r(:,2) = dexp_r(:,2) / maxY;
	dexp_b(:,2) = dexp_b(:,2) / maxY;
	dexp_k(:,2) = dexp_k(:,2) / maxY;
end
function [dexp_k,dexp_b,dexp_r] = GetDataExperFlip(dir)
	minY = 4026.6;	% obtained from Excel

	% load experimental data:
	dexp_r = load([dir,'data_exp_red.txt']);
	dexp_b = load([dir,'data_exp_blue.txt']);
	dexp_k = load([dir,'data_exp_black.txt']);
	
	% subtract lowest value
%	dexp_r(:,2) = dexp_r(:,2) - minY;
%	dexp_b(:,2) = dexp_b(:,2) - minY;
%	dexp_k(:,2) = dexp_k(:,2) - minY;
	
	% max point based on 2-top-red and 2-top-blue
	maxY = (dexp_r(1,2) + dexp_r(7,2) + dexp_b(1,2) + dexp_b(5,2)) / 4;

	dexp_r(:,2) = dexp_r(:,2) / maxY;
	dexp_b(:,2) = dexp_b(:,2) / maxY;
	dexp_k(:,2) = dexp_k(:,2) / maxY;
	
	dexp_r(:,1) = -1*dexp_r(:,1);
	dexp_b(:,1) = -1*dexp_b(:,1);
	dexp_k(:,1) = -1*dexp_k(:,1);
end
function dc = GetDataCalc(N)
	if N == 8
		cFile = { ...
			'kline_t0.100_lambda10.790_beta1.5_Uch-4.0.txt',	0.1; ...
%			'kline_t0.600_lambda9.606_beta1.5_Uch-4.0.txt',		0.6; ...
			'kline_t0.900_lambda7.407_beta1.5_Uch-4.0.txt',		0.9; ...
			'kline_t1.100_lambda4.810_beta1.5_Uch-4.0.txt',		1.1; ...
%			'kline_t1.300_lambda3.800_beta1.5_Uch-4.0.txt',		1.3; ...
			'kline_t1.320_lambda3.760_beta1.5_Uch-4.0.txt',		1.32; ...
			'kline_t1.350_lambda3.725_beta1.5_Uch-4.0.txt',		1.35; ...
%			'kline_t1.400_lambda3.650_beta1.5_Uch-4.0.txt',		1.4; ...
			%'kline_t1.450_lambda3.575_beta1.5_Uch-4.0.txt',		1.45; ...
			'kline_t1.500_lambda3.509_beta1.5_Uch-4.0.txt',		1.5; ...
			};
	elseif N == 16
		cFile = { ...
			'kline_t0.100_lambda10.790_beta1.5_Uch-4.0.txt',	0.1; ...
%			'kline_t0.600_lambda9.606_beta1.5_Uch-4.0.txt',		0.6; ...
			'kline_t0.900_lambda7.407_beta1.5_Uch-4.0.txt',		0.9; ...
			'kline_t1.100_lambda4.810_beta1.5_Uch-4.0.txt',		1.1; ...
%			'kline_t1.300_lambda3.800_beta1.5_Uch-4.0.txt',		1.3; ...
			'kline_t1.320_lambda3.760_beta1.5_Uch-4.0.txt',		1.32; ...
%			'kline_t1.330_lambda3.748_beta1.5_Uch-4.0.txt',		1.33; ...
			'kline_t1.350_lambda3.725_beta1.5_Uch-4.0.txt',		1.35; ...
%			'kline_t1.400_lambda3.650_beta1.5_Uch-4.0.txt',		1.4; ...
			'kline_t1.500_lambda3.509_beta1.5_Uch-4.0.txt',		1.5; ...
			};
	end
	
	for i = 1:size(cFile,1)
		xy = load( sprintf('N%02d_kline_data/%s',N,cFile{i,1}) );
		% normalize at Gamma point
%		xy(:,2) = xy(:,2) - xy(xy(:,1)==0.0, 2);
		% normalize at max
		xy(:,2) = xy(:,2) / max(xy(:,2));
		
		
		% create deviation data:
%		dev(i,1) = str2double( cFile{i}(8:11) );
%		dev(i,2) = GetDeviation(xy);
		
		
		dc{i,1} = xy;			%#ok
		dc{i,2} = cFile{i,2};	%#ok
	end
	
return	
	file = sprintf('N%02d_deviations.txt',N);
	fid = fopen(file, 'w');
	fprintf(fid, '% .2f  %.15f\r\n', dev');
	fclose(fid);
end
	
function dev = GetDeviation(xy)
	xy = xy(xy(:,1)>=0.0 & xy(:,1)<=0.5,:);
	xy(:,2) = xy(:,2) - 0.5;
	
	ind = find(xy(:,2) > 0, 1, 'first');
	
	p1 = xy(ind-1,:);
	p2 = xy(ind,:);
	a = (p1(2)-p2(2)) / (p1(1)-p2(1));
	b = (p1(2)*p2(1) - p2(2)*p1(1)) / (p2(1)-p1(1));
	
	dev = 0.5 - (-b/a);
end
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	