% Entry point (Hit F5 to run)
%{
===============================================================================
DESIGNED BY:    Tsezar F. Seman
AFFILIATION:    NJIT University, Physics Department
MODIFIED ON:    05/05/2012
COPYRIGHT:      (c) Tsezar F. Seman. All rights reserved.
PURPOSE:		
===============================================================================
%}
function run_t_lambda()
	clc; clear all;
	%------------------------------------------------------
	global Eg
	
	minmax_t0 = [0, 1.8];
	minmax_lambda = [0, 12];
	t0 = minmax_t0(1):0.05:minmax_t0(2);
	lambda = zeros(size(t0));
	Nt = length(t0);
	
	figure(1); clf; hold on;

	% vertical marker lines
	plot(0.1*[1,1], minmax_lambda, '-','Color',[0,.8,0], 'LineWidth',2);
	plot(0.6*[1,1], minmax_lambda, '-','Color',[0,.8,0], 'LineWidth',2);
	plot(0.9*[1,1], minmax_lambda, '-','Color',[0,.8,0], 'LineWidth',2);
	plot(1.1*[1,1], minmax_lambda, '-','Color',[0,.8,0], 'LineWidth',2);
	plot(1.4*[1,1], minmax_lambda, '-','Color',[0,.8,0], 'LineWidth',2);

	% construct dE energy gap lines
	for dE = [1.5, 1.6, 1.7, 1.8, 1.9, 2.0, 2.1];
		for i = 1:Nt
			lambda(i) = fminsearch(@(x) MinimizeF(x, t0(i), dE), 3.0);
		end
		
		if dE == 1.5 %1.2484
			plot(t0, lambda, '.-r', 'LineWidth',2, 'MarkerSize',15);
		else
			plot(t0, lambda, '.-b');
		end
		
		text(minmax_t0(1)+.02, lambda(1)-0.05, sprintf('\\Delta{E} = %.2f eV     ', dE), ...
			'BackgroundColor',[.7,.7,.9], 'FontSize',8, ...
			'HorizontalAlignment','left', 'VerticalAlignment','top');
	end
	
	% green text labels for R
	%DrawRatios();
	
	hold off;
	xlabel('t_{0} - Hopping Parameter');
	ylabel('\lambda - Hunds Parameter');
	title(sprintf('H_{nonint} Band Gap at k = (\\pi/2,0), \\beta = %.1f',Eg.C.beta));
	xlim(minmax_t0);
	ylim(minmax_lambda);
%	grid('on');
	box('on');
end
%==========================================================
function dE = Energy(lambda, t0)
	Initialize(t0, lambda);
	E = Bands_E_eg([pi/2, 0], 1, 0)';
	dE = E(3) - E(1);
end
function dz = MinimizeF(lambda, t0, dE)
	dz = abs(Energy(lambda, t0) - dE);
end
%==========================================================
function DrawRatios()
	%   [t0   lambda    R_N8  R_N16]
	data = [ ...
		[0.1, 4.337,   1.80]; ...
		[0.6, 4.608,   2.35]; ...
		[0.9, 4.341,   4.02]; ...
		[1.1, 3.380,   5.09]; ...
		];

	clrBkg = [1,.7,0];
	for i = 1:size(data,1)
		plot(data(i,1), data(i,2), 'o', 'Color',clrBkg, 'MarkerSize',8, 'LineWidth',2);
		str = sprintf('\\lambda = %.3f, R = %.2f        ', data(i,2),data(i,3));
		text(data(i,1)+.015, data(i,2)+.003, str, ...
			'BackgroundColor',clrBkg, 'FontSize',8, ...
			'HorizontalAlignment','left', 'VerticalAlignment','bottom');
	end	
end

























