%{
===============================================================================
DESIGNED BY:    Tsezar F. Seman
AFFILIATION:    NJIT University, Physics Department
MODIFIED ON:    08/18/2011
COPYRIGHT:      (c) Tsezar F. Seman. All rights reserved.
PURPOSE:        Function returns 2 H_nonint operators based on one k-space 
				value for e_g case.
INPUT:			vk = (kx,ky,kz)
===============================================================================
%}
function H = Oper_Hnonint_eg(vk)
	% ACCESS:
	global Eg
	
	H0 = H_hopping(vk, Eg.C.t0) + Eg.H_jt + Eg.H_brtng + Eg.H_shift;
	H = zeros(16,16,2);
	H(:,:,1) = H0 + Eg.H_hund(:,:,1);
	H(:,:,2) = H0 + Eg.H_hund(:,:,2);
end
%==========================================================
% Returns 16x16 matrix from one k-point:
function m16 = H_hopping(vk, t0)
	sqrt3 = sqrt(3);
	Mslice = @(k) (-t0/2) * ...
		[(cos(k(1)) + cos(k(2))),  -sqrt3*(cos(k(1)) - cos(k(2))); ...
		-sqrt3*(cos(k(1)) - cos(k(2))),  3*(cos(k(1)) + cos(k(2)))];
	m16 = blkdiag( ...
		Mslice(vk + [ 0, 0]), ...
		Mslice(vk + [ 1, 0]*pi), ...
		Mslice(vk + [ 0, 1]*pi), ...
		Mslice(vk + [ 1, 1]*pi), ...
		Mslice(vk + [-1,-1]*pi/2), ...
		Mslice(vk + [ 1,-1]*pi/2), ...
		Mslice(vk + [-1, 1]*pi/2), ...
		Mslice(vk + [ 1, 1]*pi/2) );
end
%==========================================================
