% Entry point (Hit F5 to run)
%{
===============================================================================
DESIGNED BY:    Tsezar F. Seman
AFFILIATION:    NJIT University, Physics Department
MODIFIED ON:    06/16/2012
COPYRIGHT:      (c) Tsezar F. Seman. All rights reserved.
PURPOSE:        Run all/select computational routines.
===============================================================================
%}
function run0_all()
	clear all;
	
	% system size
	N = 16;
	
	% SPECIAL DATA EXTRACTION FOR K.A.
	%{
	run2_rixs_calc(N, [0,3]);
	run5_plot_ndiff(N);	
	ExportMatrixData(N,'Case-t0.1');
	return;
	%}

	ticID = tic;
	DeleteDir_nOper(N);
	
%{
	run1_HF(N,0);
	%run4_plot_band(N);
	%return;
%}
%============================
% PHASE 1: Calc. Hartree-Fock for all CH sites
%{
	for CH = 0:8
		run1_HF(N,CH);
	end
%}
%============================
% PHASE 2: Calc. RIXS
%{
	% full energy spectrum
	%run2_rixs_calc(N);
	
	% spectrum of interest with experiment
	run2_rixs_calc(N, [0,3]);
%}
%============================
% PHASE 3: Create plots/PDFs
%{
%	run4_plot_band(N);		% !!! SET Initialize(..) to proper values
%	run5_plot_ndiff(N);

	run6_plot_rixs(N);
	
	run6_plot_rixs__PRL(N);
	run5_plot_ndiff__PRL(N);
	
%	copyfile(sprintf('_N%02d_data_/_tables_/N%02d_CH0__nXptTable.txt',N,N),'_PDF_');
	copyfile(sprintf('_N%02d_data_/_tables_/N%02d_CH0__SysParams.txt',N,N),'_PDF_');

%	run7_dos_nenh(N);
%}
%============================
%{-
	% spectrum of interest with experiment	
	run2_rixs_calc_ext(N);
	%run2_rixs_calc_ext(N, [0,3]);

	run6_plot_rixs_ext(N);
%}
%============================
% FINILIZE:
	TimeElapsed(ticID);
	DeleteDir_nOper(N);
%============================
end

% remove temp folder with n-operators
function DeleteDir_nOper(N)
	% remove temp folder with n-operators
	dir = sprintf('_nOper_N%02d_',N);
	if exist(dir,'dir') ~= 0; rmdir(dir,'s'); end;
end

function ExportMatrixData(N, stCase)
	dirTo = sprintf('Export_N%02d_%s',N,stCase);
	if exist(dirTo,'dir') == 0
		mkdir(dirTo);
	end
	
	dirFrom = sprintf('_N%02d_data_/_tables_',N);
	copyfile(sprintf('%s/N%02d_CH0__SysParams.txt',dirFrom,N), dirTo);
	copyfile(sprintf('%s/N%02d__kMap_kx-ky.txt',dirFrom,N), dirTo);
	copyfile(sprintf('%s/N%02d__kMap_matrix_rixs.txt',dirFrom,N), dirTo);
	copyfile(sprintf('%s/N%02d__nDiff_ix-iy.txt',dirFrom,N), dirTo);
	copyfile(sprintf('%s/N%02d__nDiff_matrix_Mn3x.txt',dirFrom,N), dirTo);
	copyfile(sprintf('%s/N%02d__nDiff_matrix_Mn3y.txt',dirFrom,N), dirTo);
	copyfile(sprintf('%s/N%02d__nDiff_matrix_Mn4.txt',dirFrom,N), dirTo);
end






















