% Entry point (Hit F5 to run)
%{
===============================================================================
DESIGNED BY:    Tsezar F. Seman
AFFILIATION:    NJIT University, Physics Department
MODIFIED ON:    08/16/2011
COPYRIGHT:      (c) Tsezar F. Seman. All rights reserved.
PURPOSE:        Program displays colored difference of n-tables in 3D.
===============================================================================
%}
function run5_plot_ndiff(N)
	clc; addpath('_functions_','_common_');
	if nargin < 1
		clear all;
		N = 16;
	end
	isSavePDF = 0;
	isSaveEPS = 0;
	%------------------------------------------------------
	fprintf('nXpt DIFFERENCES FOR LaSrMnO4\n=============================\n');
	fprintf('## LOADING GENERATED DATA: ... \n');
	SetGlobals(N);
	t0 = Get_t0();
	
%{-
	%--------------------------------------------
	% SPECIAL PLOTTING FOR EPS REPORT:
	tcase = sprintf('-t%.1f',t0);
	Plot_nDiffAll__PRB();
	if isSaveEPS
		fig2eps(gcf-1,	sprintf('i-map-Mn3%s',tcase));
		fig2eps(gcf,	sprintf('i-map-Mn4%s',tcase));
	end
%return;
%}	
	
	%------------------------------------------------------
	% PLOTS:
	fprintf('\n## GENERATING PLOTS: ... \n');
%{
	Plot_nDiff();
	if isSavePDF
		for i = 1:4
			fig2pdf(gcf-4+i,sprintf('N%02i_CH%i_p1_nDiff_',N,i));
		end
	end
%}
%{
	Plot_nDiffAll();
	if isSavePDF
		for i = 1:4
			fig2pdf(gcf-4+i,sprintf('N%02i_CH%i_p1_nDiff_Full_',N,i));
		end
	end
%}
	%------------------------------------------------------
	% TABLES:
	fprintf('\n## SAVING TABLES: ... \n');
	Table_nDiff();
	Table_Matrix();
end
%==========================================================
function t0 = Get_t0()
	global GL
	
	t0 = GL.C.t0;
end
function SetGlobals(N)
	global GL
	
	path = sprintf('_N%02i_data_/_nDiff_',N);
	CH0=[]; CH1=[]; CH2=[]; CH3=[]; CH4=[];
	load(sprintf('%s/N%02i_CH0.mat',path,N));
	load(sprintf('%s/N%02i_CH1.mat',path,N));
	load(sprintf('%s/N%02i_CH2.mat',path,N));
	load(sprintf('%s/N%02i_CH3.mat',path,N));
	load(sprintf('%s/N%02i_CH4.mat',path,N));
	
	if CH0.Uch_eg ~= CH1.Uch_eg || CH0.Uch_eg ~= CH2.Uch_eg || ...
			CH0.Uch_eg ~= CH3.Uch_eg || CH0.Uch_eg ~= CH4.Uch_eg
		error('ERR: Uch_eg Mismatch Among Files.');
	end
	
	GL = CH0;
	GL = rmfield(GL, 'nXpt_list');
	GL.dir_tables = sprintf('_N%02i_data_/_tables_',N);
	
	prEg = sprintf('E_{g}');
	GL.cTitles = {...
		sprintf('%s: \\Delta n_{-,\\uparrow}', prEg),...
		sprintf('%s: \\Delta n_{+,\\uparrow}', prEg),...
		sprintf('%s: \\Delta n_{-,\\downarrow}', prEg),...
		sprintf('%s: \\Delta n_{+,\\downarrow}', prEg)};
	
	GL.nDiff = zeros(size(CH0.nXpt_list,1),4,4);
	GL.nDiff(:,:,1) = CH1.nXpt_list - CH0.nXpt_list;
	GL.nDiff(:,:,2) = CH2.nXpt_list - CH0.nXpt_list;
	GL.nDiff(:,:,3) = CH3.nXpt_list - CH0.nXpt_list;
	GL.nDiff(:,:,4) = CH4.nXpt_list - CH0.nXpt_list;
	
	GL.nDiffAll = zeros(size(CH0.nXpt_list,1),1,4);
	for ich = 1:4
		GL.nDiffAll(:,1,ich) = GL.nDiff(:,1,ich) + GL.nDiff(:,2,ich) + GL.nDiff(:,3,ich) + GL.nDiff(:,4,ich);
	end

	GL.CH_site = zeros(4,3);
	GL.CH_site(1,:) = CH1.CH_site;
	GL.CH_site(2,:) = CH2.CH_site;
	GL.CH_site(3,:) = CH3.CH_site;
	GL.CH_site(4,:) = CH4.CH_site;
end

function Plot_ColoredAtoms(subId, data_C, minmax_C, szTitle, CH_site)
	global GL
	
	MS = 40;	% marker size limits
	if GL.N >=12
		MS = .7*MS;
	end
	nPt = size(GL.iPoints,1);
	
	% define orbital loops
	orb_size = 0.5;
	th = 0:0.1:2*pi+0.1;
	r_hor = orb_size * cos(th).^2;
	r_ver = orb_size * sin(th).^2;
	xy_hor = [r_hor.*cos(th); r_hor.*sin(th)];
	xy_ver = [r_ver.*cos(th); r_ver.*sin(th)];
	clrCH =  [1 1 1]*.93;
	clrOrb = [1 1 1]*.6;
	clrZig = [1 1 1]*.6;
	
	if subId > 0
		subplot(2,2,subId);
	else
		subplot(1,1,1);
		MS = MS*2;
	end
	hold on;
	% draw CH site
	plot(CH_site(1),CH_site(2),'.', 'Color',clrCH, 'MarkerSize',MS*3);

	% draw zig-zag and orbitals
	for iPt = 1:nPt
		x = GL.iPoints(iPt,1);
		y = GL.iPoints(iPt,2);
		switch GL.iPoints(iPt,3)
			case 1
				plot(x+[-1 1],y+[0 0],'-', 'Color',clrZig,'LineWidth',3);
				plot(x+xy_hor(1,:),y+xy_hor(2,:),'-', 'Color',clrOrb);
			case 3
				plot(x+[0 0],y+[-1 1],'-', 'Color',clrZig,'LineWidth',3);
				plot(GL.iPoints(iPt,1)+xy_ver(1,:),GL.iPoints(iPt,2)+xy_ver(2,:),'-', 'Color',clrOrb);
		end
	end
	% draw color dots
	nC = 64;
	cmap = colormap( jet(nC) );
	for iPt = 1:nPt
		q = (data_C(iPt) - minmax_C(1)) ./ (minmax_C(2) - minmax_C(1));
		iColor = max( 1, min(nC, round((nC-1)*q+1) ) );
		plot(GL.iPoints(iPt,1),GL.iPoints(iPt,2),'.', 'MarkerSize',MS, 'Color',cmap(iColor,:));
	end
	hold off;
	axis('equal');
	box on;
	%colorbar;
	caxis(minmax_C);
	minmax_xy = [min(GL.iPoints(:,1)), max(GL.iPoints(:,1))];
	xlim(minmax_xy + [-.6, .6]);
	ylim(minmax_xy + [-.6, .6]);
	title(szTitle);
	xlabel('i_x');
	ylabel('i_y');
	set(gca,'XTick',(minmax_xy(1):minmax_xy(2)))
	set(gca,'YTick',(minmax_xy(1):minmax_xy(2)))
end
function Plot_nDiff()
	global GL

	for iCH = 1:4
		mm = max(max( abs(GL.nDiff(:,:,iCH)) ));
		minmax_C = [-mm, mm]/1;
	
		GL.figId = FigId(GL.figId,''); clf; subplot(1,1,1);
		for i = 1:4
			Plot_ColoredAtoms(i, GL.nDiff(:,i,iCH), minmax_C, GL.cTitles{i}, GL.CH_site(iCH,:));
		end
		
		% title
		szTitle = sprintf('N=%i, CH=%i: E_g Colorbar (U = %.1f, U_{ch} = %.1f), bounds: [%.2f, %.2f]', ...
			GL.N, iCH, GL.U_eg, GL.Uch_eg, minmax_C(1), minmax_C(2));
		
		% colorbar
		hax = axes('Position', [.27, .51, .5, .02]);
		nC = 64;
		cmap = colormap(jet(nC));
		y_lim = [0, mm/2];
		x = -mm; dx = 2*mm/nC;
		hold on;
		for i=1:nC
			plot([x, x]+dx/2, y_lim, 'Color',cmap(i,:), 'LineWidth',8);
			x = x + dx;
		end
		hold off;
		title(szTitle);	
		xlim([-mm, mm]);
		ylim(y_lim);
		set(hax,'YTick',[], 'TickDir','out', 'Box','on');
		
		fprintf('    * Figure %i: %s.\n',(GL.figId-1),szTitle);
	end
end
function Plot_nDiffAll()
	global GL

	for iCH = 1:4
		mm = max(max( abs(GL.nDiffAll(:,1,iCH)) ));
		minmax_C = [-mm, mm]/1;
	
		GL.figId = FigId(GL.figId,''); clf; subplot(1,1,1);
		% title
		szTitle = sprintf('N=%i, CH=%i: Total Electron Number Change, bounds: [%.2f, %.2f]', ...
			GL.N, iCH, minmax_C(1), minmax_C(2));
		Plot_ColoredAtoms(-1, GL.nDiffAll(:,1,iCH), minmax_C, szTitle, GL.CH_site(iCH,:));
		
		% colorbar
		hax = axes('Position', [.27, .08, .5, .02]);
		nC = 64;
		cmap = colormap(jet(nC));
		y_lim = [0, mm/2];
		x = -mm; dx = 2*mm/nC;
		hold on;
		for i=1:nC
			plot([x, x]+dx/2, y_lim, 'Color',cmap(i,:), 'LineWidth',8);
			x = x + dx;
		end
		hold off;
		%title(szTitle);
		xlim([-mm, mm]);
		ylim(y_lim);
		set(hax,'YTick',[], 'TickDir','out', 'Box','on');

		fprintf('    * Figure %i: %s.\n',(GL.figId-1),szTitle);
	end
end

function Table_nDiff()
	global GL

	for iCH = 1:4
		data = [GL.iPoints, GL.nDiff(:,:,iCH), sum(GL.nDiff(:,:,iCH), 2)];
		cType = {'Mn3x','Mn4 ','Mn3y'};
		file = sprintf('%s/N%02i_CH%i__nDiff.txt',GL.dir_tables,GL.N,iCH);
		fid = fopen(file, 'w');
		fprintf(fid, '+--------------------------------------------------+\r\n');
		fprintf(fid, '| N = %2i: ELECTRON NUMBER TABLE (CH = %i)           |\r\n',GL.N,iCH);
		fprintf(fid, '+------+------+-----------------------------+------+\r\n');
		fprintf(fid, ' i-pos | orb. |     eg case: < n_{..} >     | sum(n)\r\n');
		fprintf(fid, ' ix iy | type | -,up   +,up   -,dn   +,dn   |       \r\n');
		fprintf(fid, '-------+------+-----------------------------+-------\r\n');
		for i = 1:size(data,1)
			fprintf(fid, ' % i % i | %s |% 6.4f% 6.4f% 6.4f% 6.4f |% 6.4f\r\n', ...
				data(i,1:2), cType{data(i,3)}, data(i,4:8)  );
		end
		fprintf(fid, '-------+------+-----------------------------+-------\r\n');
		fclose(fid);
		
%sum(GL.nDiff(:,:,iCH),1)

		fprintf('    * Table file [%s] have been generated.\n',file);
	end
end
function Table_Matrix()
	global GL
	
	sPref = sprintf('%s/N%02i__nDiff',GL.dir_tables,GL.N);
	
	ixy = GL.iPoints(1:GL.N,1);
	file = sprintf('%s_ix-iy.txt',sPref);
	fid = fopen(file, 'w');
	fprintf(fid, 'ix values:\r\n');
	fprintf(fid, '% d ',ixy);
	fprintf(fid, '\r\n\r\niy values:\r\n');
	fprintf(fid, '% d\r\n',flipud(ixy));
	fclose(fid);
	
	
	cMn = {'Mn3x','Mn4','Mn3y','Mn4'};
	for iCH = 1:3
		nD = sum(GL.nDiff(:,:,iCH), 2);
		nD2 = flipud(reshape(nD, GL.N, GL.N)');
		file = sprintf('%s_matrix_%s.txt',sPref,cMn{iCH});
		fid = fopen(file, 'w');
		for ir = 1:size(nD2,1)
			fprintf(fid, ' % .16f',nD2(ir,:));
			fprintf(fid, '\r\n');
		end
		fclose(fid);

		fprintf('    * Table file [%s] have been generated.\n',file);
	end
end
%==========================================================
% SPECIAL for EPS:
function Plot_nDiffAll__PRB()
	global GL
	
	CH = [1,2];
	FontSize = 20;
	%----------------------------------------
	% case CH=2
	GL.figId = FigId(GL.figId,'');
	subplot(1,1,1);	clf; hold on;

	offset = [0,0];
	mm = max(max( abs(GL.nDiffAll(:,1,CH(1))) ));
mm
	mmCH2 = max(max( abs(GL.nDiffAll(:,1,CH(2))) ));
mmCH2


	minmax_C1 = [-mm, mm];	
	DrawBackground__PRB();
	DrawColDots__PRB(GL.nDiffAll(:,1,CH(1)), offset, minmax_C1, mmCH2);
title(sprintf('max = %g',mm));

	%{
	% white letters centered
    text(offset(1), offset(2), 'Mn^{3+}', ...
        'FontSize',FontSize, 'Color','w', 'FontWeight','bold', ...
        'HorizontalAlignment','center', 'VerticalAlignment','middle');
	%}
	%{
	% black letters below
	text(offset(1), offset(2)-0.4, 'Mn^{3+}', ...
        'FontSize',FontSize, 'Color','k', 'FontWeight','bold', ...
        'HorizontalAlignment','center', 'VerticalAlignment','middle');
	%}
	
	% finalize
	hold off;
	camva(1.2*camva);	
	fprintf('    * Figure %i: %s.\n',(GL.figId-1),' nDiff Merged');
	%----------------------------------------
	% case CH=2
	GL.figId = FigId(GL.figId,'');
	subplot(1,1,1);	clf; hold on;

	offset = [0,0];
	mm = mmCH2;
mm
	minmax_C2 = [-mm, mm];
	DrawBackground__PRB();
	DrawColDots__PRB(GL.nDiffAll(:,1,CH(2)), offset, minmax_C2, mm);
title(sprintf('max = %g',mm));
	%{
    text(offset(1)+1, offset(2), 'Mn^{4+}', ...
        'FontSize',FontSize, 'Color','w', 'FontWeight','bold', ...
        'HorizontalAlignment','center', 'VerticalAlignment','middle');
	%}
	% finalize
	hold off;
	camva(1.2*camva);	
	fprintf('    * Figure %i: %s.\n',(GL.figId-1),' nDiff Merged');
end
function DrawBackground__PRB()
	global GL
	
	FontSize = 25;
	
	nPt = size(GL.iPoints,1);
	
	% define orbital loops
	orb_size = 0.5;
	th = 0:0.1:2*pi+0.1;
	r_hor = orb_size * cos(th).^2;
	r_ver = orb_size * sin(th).^2;
	xy_hor = [r_hor.*cos(th); r_hor.*sin(th)];
	xy_ver = [r_ver.*cos(th); r_ver.*sin(th)];
	clrOrb = [1 1 1]*0.8;
	clrZig = [1 1 1]*0.7;

	% draw zig-zag
	lw = 1.5;
	minmax_Zig = [-16, 16];
	for i = minmax_Zig(1):minmax_Zig(2)
		arX = [i-1, i+1];
		arY = [-i, -i];
		dir = 1;
		while (arX(1) > minmax_Zig(1)) && (arX(length(arX)) < minmax_Zig(2))
			if mod(dir,2)==1
				arX	= [arX(1),	arX, arX(length(arX))];
				arY = [arY(1)-2,arY, arY(length(arY))+2];
			else
				arX	= [arX(1)-2,arX, arX(length(arX))+2];
				arY = [arY(1),	arY, arY(length(arY))];
			end
			dir = dir+1;
		end
		if mod(i,2)==0
			line = '-';
		else
			line = '--';
		end
		plot(arX, arY, line, 'Color',clrZig,'LineWidth',lw);
	end
	% draw orbitals
	lw = 1.5;
	for iPt = 1:nPt
		x = GL.iPoints(iPt,1);
		y = GL.iPoints(iPt,2);
		switch GL.iPoints(iPt,3)
			case 1
				%plot(x+[-1 1],y+[0 0],'-', 'Color',clrZig,'LineWidth',5);
				plot(x+xy_hor(1,:),y+xy_hor(2,:),'-', 'Color',clrOrb, 'LineWidth',lw);
			case 3
				%plot(x+[0 0],y+[-1 1],'-', 'Color',clrZig,'LineWidth',5);
				plot(GL.iPoints(iPt,1)+xy_ver(1,:),GL.iPoints(iPt,2)+xy_ver(2,:),'-', 'Color',clrOrb, 'LineWidth',lw);
		end
	end
		
	axis('equal');
	box on;
%	minmax_xy = [-3,3];
	minmax_xy = [-7,8];
	limits_xy = minmax_xy + [-.22, .22];
	xlim(limits_xy);
	ylim(limits_xy);
%{
	xlabel('i_x', 'FontSize',FontSize);
	ylabel('i_y', 'FontSize',FontSize);
	set(gca,'XTick',-4:5);
	set(gca,'YTick',-4:5);
	TickLabels = {'-4';'';'-2';'';'0';'';'2';'';'4';''};
	set(gca,'XTickLabel',TickLabels);
	set(gca,'YTickLabel',TickLabels);
%	set(gca, 'XAxisLocation','top');
	set(gca, 'TickDir','out');
%}
	set(gca,'XTick',[]);
	set(gca,'YTick',[]);
	
	set(gca, 'FontSize',FontSize);
	set(gca, 'LineWidth',2);
end
function DrawColDots__PRB(data_C, offset, minmax_C, maxC)
	global GL
	
	% draw color dots
	function MS = DotSize(msMin,msMax, q)
%		MS = msMin + msMax * sqrt(2*abs(q - 0.5));
		MS = msMin + msMax * (2*abs(q - 0.5))^(1/3);	% volume based
		if MS < 1e-13
			MS = 1e-16;
		end
	end

	nPt = size(GL.iPoints,1);
	
	colPos = [.8 0 0];
	colNeg = [0 0 .8];
	scaleC = minmax_C(2) / maxC;

	for iPt = 1:nPt
		q = (scaleC*data_C(iPt) - minmax_C(1)) ./ (minmax_C(2) - minmax_C(1));
		%iColor = max( 1, min(nC, round((nC-1)*q+1) ) );
		if data_C(iPt) > 0
			colDot = colPos;
		else
			colDot = colNeg;
		end

		%marSize = DotSize(0,40, q);
		marSize = DotSize(0,30, q);
		plot(GL.iPoints(iPt,1)+offset(1),GL.iPoints(iPt,2)+offset(2),'o', ...
			'MarkerSize',marSize, 'MarkerEdgeColor','none', ...
			'MarkerFaceColor',colDot);
	end
end


































