% Entry point (Hit F5 to run)
%{
===============================================================================
DESIGNED BY:    Tsezar F. Seman
AFFILIATION:    NJIT University, Physics Department
MODIFIED ON:    08/16/2011
COPYRIGHT:      (c) Tsezar F. Seman. All rights reserved.
PURPOSE:        Program displays colored difference of n-tables in 3D.
===============================================================================
%}
function run5_plot_ndiff__PRL(N)
	clc; addpath('_functions_','_common_');
	if nargin < 1
		clear all;
		N = 16;
	end

	isSaveEPS = 1;
	isSavePDF = 0;
	%------------------------------------------------------
	fprintf('nXpt DIFFERENCES FOR LaSrMnO4\n=============================\n');
	fprintf('## LOADING GENERATED DATA: ... \n');
	SetGlobals(N);
	
%{-
	%--------------------------------------------
	% SPECIAL PLOTTING FOR EPS REPORT:
%	Plot_nDiffAll__SpecialMerged();
    Plot_nDiffAll__SpecialMerged_v2();
	if isSaveEPS
		fig2eps(gcf,'i-map-ndiff');
	end
	if isSavePDF
		fig2pdf(gcf, sprintf('N%02d_CH0_nDiff__PRL_',N));
	end
	return
%}
	

	PlotAlongZigzag(N, 1);
	PlotAlongZigzag(N, 2);
end
%==========================================================
function SetGlobals(N)
	global GL
	
	path = sprintf('_N%02i_data_/_nDiff_',N);
	CH0=[]; CH1=[]; CH2=[]; CH3=[]; CH4=[];
	load(sprintf('%s/N%02i_CH0.mat',path,N));
	load(sprintf('%s/N%02i_CH1.mat',path,N));
	load(sprintf('%s/N%02i_CH2.mat',path,N));
	load(sprintf('%s/N%02i_CH3.mat',path,N));
	load(sprintf('%s/N%02i_CH4.mat',path,N));
	
	if CH0.Uch_eg ~= CH1.Uch_eg || CH0.Uch_eg ~= CH2.Uch_eg || ...
			CH0.Uch_eg ~= CH3.Uch_eg || CH0.Uch_eg ~= CH4.Uch_eg
		error('ERR: Uch_eg Mismatch Among Files.');
	end
	
	GL = CH0;
	GL = rmfield(GL, 'nXpt_list');
	GL.dir_tables = sprintf('_N%02i_data_/_tables_',N);
	
	prEg = sprintf('E_{g}');
	GL.cTitles = {...
		sprintf('%s: \\Delta n_{-,\\uparrow}', prEg),...
		sprintf('%s: \\Delta n_{+,\\uparrow}', prEg),...
		sprintf('%s: \\Delta n_{-,\\downarrow}', prEg),...
		sprintf('%s: \\Delta n_{+,\\downarrow}', prEg)};
	
	GL.nDiff = zeros(size(CH0.nXpt_list,1),4,4);
	GL.nDiff(:,:,1) = CH1.nXpt_list - CH0.nXpt_list;
	GL.nDiff(:,:,2) = CH2.nXpt_list - CH0.nXpt_list;
	GL.nDiff(:,:,3) = CH3.nXpt_list - CH0.nXpt_list;
	GL.nDiff(:,:,4) = CH4.nXpt_list - CH0.nXpt_list;
	
	GL.nDiffAll = zeros(size(CH0.nXpt_list,1),1,4);
	for ich = 1:4
		GL.nDiffAll(:,1,ich) = GL.nDiff(:,1,ich) + GL.nDiff(:,2,ich) + GL.nDiff(:,3,ich) + GL.nDiff(:,4,ich);
	end

	GL.CH_site = zeros(4,3);
	GL.CH_site(1,:) = CH1.CH_site;
	GL.CH_site(2,:) = CH2.CH_site;
	GL.CH_site(3,:) = CH3.CH_site;
	GL.CH_site(4,:) = CH4.CH_site;
end
%==========================================================
function PlotAlongZigzag(N, CH)
	global GL
	
	if N ~= 16; return; end;
		
	GL.figId = FigId(GL.figId,'');

	nDiffAll = GL.nDiffAll(:,1, CH);
	% normalize to 1 at C-H site
	nDiffAll = nDiffAll ./ max(nDiffAll);

	sh = [0,1; 1,0; 1,0; 0,1];
	pt = [-7,-7];
	ish = 1;
	i = 1;
	while pt(1) < 9 || pt(2) < 8
		ind = find(GL.iPoints(:,1)==pt(1) & GL.iPoints(:,2)==pt(2));
		nDiff(i) = nDiffAll(ind);	i = i+1;
		pt = pt+sh(ish,:);
		ish = mod(ish,4)+1;
	end

	% plotting
	[m,ind] = max(nDiff);
	xvals = (1:length(nDiff)) - ind;
	
	xvals = 1:8;
	nDiff = nDiff(ind:-1:1) + nDiff(ind:2*ind-1);
	nDiff = nDiff(1+(xvals));

%	plot(xvals, nDiff, '.-b')
	semilogy(xvals, nDiff, '.-b')
	
	Y = log(-nDiff);	
	p = polyfit(xvals,Y,1);	
	lam = -1/p(1);
	A = exp(p(2));
[A, lam]
	
[xvals; nDiff]'


	xF = 1:0.01:8;
	yF = -A*exp(-xF./lam);
	hold on
%	plot(xF,yF,'-r')
	semilogy(xF,yF,'-r')
	
	hold off
	axis('tight');
	ylim([-1,-1e-16]);
	xlim([0,8])

	ylabel('n-Difference')
	xlabel('Distance along zigzag chain form C-H')
	
	
%{-
	suf = sprintf('_t%0.2f_CH%d', GL.C.t0,CH);

	% exporting zigzag data:
	MakeDir('_EXPORT_');
	file = sprintf('_EXPORT_/zigzag%s.txt',suf);
	fid = fopen(file, 'w');
	data = [xvals; nDiff];
	fprintf(fid, '% .1f  % .16f\r\n', data);
	fclose(fid);
	fprintf('    * File [%s] have been generated.\n',file);

	% exporting fitting parameters:
	file = sprintf('_EXPORT_/zigzag%s_fit-param.txt',suf);
	fid = fopen(file, 'w');
	data = [A, lam];
	fprintf(fid, '% .16f  % .16f\r\n', data);
	fclose(fid);
	fprintf('    * File [%s] have been generated.\n',file);
%}
end

% SPECIAL for EPS:
function Plot_nDiffAll__SpecialMerged()
	global GL

	GL.figId = FigId(GL.figId,'');
%	subplot(1,1,1);
	clf; hold on;
	
	DrawBackground__SpecialMerged();
	
	CH = [1,2];
	% plot data for CH1 and CH2
	offset1 = [-2, -2];
	mm = max(max( abs(GL.nDiffAll(:,1,CH(1))) ));
	minmax_C1 = [-mm, mm];
minmax_C1

	offset2 = [2, 2];
	mm = max(max( abs(GL.nDiffAll(:,1,CH(2))) ));
	minmax_C2 = [-mm, mm];
minmax_C2	
	maxC = max(minmax_C1(2), minmax_C2(2));
	
	DrawColDots_SpecialMerged(GL.nDiffAll(:,1,CH(1)), offset1, minmax_C1, maxC);
	DrawColDots_SpecialMerged(GL.nDiffAll(:,1,CH(2)), offset2, minmax_C2, maxC);
	
	% finalize
	hold off;
%	camva(1.2*camva);
	
	fprintf('    * Figure %i: %s.\n',(GL.figId-1),' nDiff Merged');
end
function DrawBackground__SpecialMerged()
	global GL
	
	FontSize = 20;
	
	nPt = size(GL.iPoints,1);
	
	% define orbital loops
	orb_size = 0.5;
	th = 0:0.1:2*pi+0.1;
	r_hor = orb_size * cos(th).^2;
	r_ver = orb_size * sin(th).^2;
	xy_hor = [r_hor.*cos(th); r_hor.*sin(th)];
	xy_ver = [r_ver.*cos(th); r_ver.*sin(th)];
	clrOrb = [1 1 1]*0.8;
	clrZig = [1 1 1]*0.7;

	% draw zig-zag
	minmax_Zig = [-16, 16];
	for i = minmax_Zig(1):minmax_Zig(2)
		arX = [i-1, i+1];
		arY = [-i, -i];
		dir = 1;
		while (arX(1) > minmax_Zig(1)) && (arX(length(arX)) < minmax_Zig(2))
			if mod(dir,2)==1
				arX	= [arX(1),	arX, arX(length(arX))];
				arY = [arY(1)-2,arY, arY(length(arY))+2];
			else
				arX	= [arX(1)-2,arX, arX(length(arX))+2];
				arY = [arY(1),	arY, arY(length(arY))];
			end
			dir = dir+1;
		end
		if mod(i,2)==0
			line = '-';
		else
			line = '--';
		end
		plot(arX, arY, line, 'Color',clrZig,'LineWidth',3)
	end
	% draw orbitals
	for iPt = 1:nPt
		x = GL.iPoints(iPt,1);
		y = GL.iPoints(iPt,2);
		switch GL.iPoints(iPt,3)
			case 1
				%plot(x+[-1 1],y+[0 0],'-', 'Color',clrZig,'LineWidth',5);
				plot(x+xy_hor(1,:),y+xy_hor(2,:),'-', 'Color',clrOrb, 'LineWidth',2);
			case 3
				%plot(x+[0 0],y+[-1 1],'-', 'Color',clrZig,'LineWidth',5);
				plot(GL.iPoints(iPt,1)+xy_ver(1,:),GL.iPoints(iPt,2)+xy_ver(2,:),'-', 'Color',clrOrb, 'LineWidth',2);
		end
	end
		
	axis('equal');
	box on;
	minmax_xy = [-4.5,5];
	limits_xy = minmax_xy + [-.22, .22];
	xlim(limits_xy);
	ylim(limits_xy);
	xlabel('i_x', 'FontSize',FontSize);
	ylabel('i_y', 'FontSize',FontSize);
	set(gca,'XTick',-4:5);
	set(gca,'YTick',-4:5);
	TickLabels = {'-4';'';'-2';'';'0';'';'2';'';'4';''};
	set(gca,'XTickLabel',TickLabels);
	set(gca,'YTickLabel',TickLabels);
%	set(gca, 'XAxisLocation','top');
	
	set(gca, 'TickDir','out', 'FontSize',FontSize);
	set(gca, 'LineWidth',2);

	% diagonal line accross
	plot(limits_xy,[limits_xy(2),limits_xy(1)],'-k', 'LineWidth',4);
%{
	% fig (a) and (b) labels
	text(-4,3.25, '(a)', 'FontSize',FontSize, 'Color',[0 0 0], ...
		'HorizontalAlignment','center', 'VerticalAlignment','middle', ...
		 'BackgroundColor',[1 1 1], 'EdgeColor',[0 0 0], 'LineWidth',2, 'Margin',5);
	text(-2.75,4.5, '(b)', 'FontSize',FontSize, 'Color',[0 0 0], ...
		'HorizontalAlignment','center', 'VerticalAlignment','middle', ...
		 'BackgroundColor',[1 1 1], 'EdgeColor',[0 0 0], 'LineWidth',2, 'Margin',5);
%}
	% Mn3/4 labels
	FigText(-0.9,-2.4, 'Mn^{3+}', FontSize);
	FigText(4.15, 1.55, 'Mn^{4+}', FontSize);
	%annotation(gcf,'arrow',[0.5 0.9],[0.7,0.7]);
end
function DrawColDots_SpecialMerged(data_C, offset, minmax_C, maxC)
	global GL
	
	% draw color dots
	function MS = DotSize(msMin,msMax, q)
		MS = msMin + msMax * sqrt(2*abs(q - 0.5));
	end

	nPt = size(GL.iPoints,1);
	
	colPos = [.8 0 0];
	colNeg = [0 0 .8];
	scaleC = minmax_C(2) / maxC;

	for iPt = 1:nPt
		bVal = isInSameHalf(GL.iPoints(iPt,1:2)+offset, offset);
		if bVal	== 1
			q = (scaleC*data_C(iPt) - minmax_C(1)) ./ (minmax_C(2) - minmax_C(1));
			%iColor = max( 1, min(nC, round((nC-1)*q+1) ) );
			if data_C(iPt) > 0
				colDot = colPos;
			else
				colDot = colNeg;
			end

			marSize = DotSize(0,40, q);
			marSize = max(marSize, 1e-6);

			plot(GL.iPoints(iPt,1)+offset(1),GL.iPoints(iPt,2)+offset(2),'o', ...
				'MarkerSize',marSize, 'MarkerEdgeColor','none', ...
				'MarkerFaceColor',colDot);
		end
	end
end
function bVal = isInSameHalf(iPoint, offset)
	% threshold line is: y = -x + 0.5
	bVal = 0;
	if offset(1)+offset(2) < 0.5
		if iPoint(1)+iPoint(2) < 0.5
			bVal = 1;
		end
	else
		if iPoint(1)+iPoint(2) > 0.5
			bVal = 1;
		end
	end
end




function Plot_nDiffAll__SpecialMerged_v2()
	global GL

	GL.figId = FigId(GL.figId,'');
%	subplot(1,1,1);
	clf; hold on;
	
	DrawBackground__SpecialMerged_v2();
	
	CH = [1,2];
	% plot data for CH1 and CH2
%	offset1 = [0, 0];
%    offset1 = [2, 2];
    offset1 = [-2, -2];
	mm = max(max( abs(GL.nDiffAll(:,1,CH(1))) ));
	minmax_C1 = [-mm, mm];
minmax_C1

%	offset2 = [2, -2];
    offset2 = [4, 0];
	mm = max(max( abs(GL.nDiffAll(:,1,CH(2))) ));
	minmax_C2 = [-mm, mm];
minmax_C2	
	maxC = max(minmax_C1(2), minmax_C2(2));
	
	DrawColDots_SpecialMerged_v2(GL.nDiffAll(:,1,CH(1)), offset1, minmax_C1, maxC);
	DrawColDots_SpecialMerged_v2(GL.nDiffAll(:,1,CH(2)), offset2, minmax_C2, maxC);
	
	% Mn3/4 labels
    FontSize = 20;
	FigText(offset1(1)+0.75, offset1(2)-0.5, 'Mn^{3+}', FontSize);
%	FigText(offset2(1)+1.5, offset2(2)-0.65, 'Mn^{4+}', FontSize);


    text(offset1(1), offset1(2), 'Mn^{3+}', ...
        'FontSize',FontSize, 'Color','w', 'FontWeight','bold', ...
        'HorizontalAlignment','center', 'VerticalAlignment','middle');
    
    text(offset2(1)+1, offset2(2), 'Mn^{4+}', ...
        'FontSize',FontSize, 'Color','w', 'FontWeight','bold', ...
        'HorizontalAlignment','center', 'VerticalAlignment','middle');
    
	% finalize
	hold off;
%	camva(1.2*camva);

    title(sprintf('t_0 = %.1f eV',GL.C.t0))
	
	fprintf('    * Figure %i: %s.\n',(GL.figId-1),' nDiff Merged');
end
function DrawBackground__SpecialMerged_v2()
	global GL
	
	FontSize = 20;
	
	nPt = size(GL.iPoints,1);
	
	% define orbital loops
	orb_size = 0.5;
	th = 0:0.1:2*pi+0.1;
	r_hor = orb_size * cos(th).^2;
	r_ver = orb_size * sin(th).^2;
	xy_hor = [r_hor.*cos(th); r_hor.*sin(th)];
	xy_ver = [r_ver.*cos(th); r_ver.*sin(th)];
	clrOrb = [1 1 1]*0.8;
	clrZig = [1 1 1]*0.7;

	% draw zig-zag
	minmax_Zig = [-16, 16];
	for i = minmax_Zig(1):minmax_Zig(2)
		arX = [i-1, i+1];
		arY = [-i, -i];
		dir = 1;
		while (arX(1) > minmax_Zig(1)) && (arX(length(arX)) < minmax_Zig(2))
			if mod(dir,2)==1
				arX	= [arX(1),	arX, arX(length(arX))];
				arY = [arY(1)-2,arY, arY(length(arY))+2];
			else
				arX	= [arX(1)-2,arX, arX(length(arX))+2];
				arY = [arY(1),	arY, arY(length(arY))];
			end
			dir = dir+1;
		end
		if mod(i,2)==0
			line = '-';
		else
			line = '--';
		end
		plot(arX, arY, line, 'Color',clrZig,'LineWidth',3)
	end
	% draw orbitals
	for iPt = 1:nPt
		x = GL.iPoints(iPt,1);
		y = GL.iPoints(iPt,2);
		switch GL.iPoints(iPt,3)
			case 1
				%plot(x+[-1 1],y+[0 0],'-', 'Color',clrZig,'LineWidth',5);
				plot(x+xy_hor(1,:),y+xy_hor(2,:),'-', 'Color',clrOrb, 'LineWidth',2);
			case 3
				%plot(x+[0 0],y+[-1 1],'-', 'Color',clrZig,'LineWidth',5);
				plot(GL.iPoints(iPt,1)+xy_ver(1,:),GL.iPoints(iPt,2)+xy_ver(2,:),'-', 'Color',clrOrb, 'LineWidth',2);
		end
	end
		
	axis('equal');
	box on;
    margin = [-.1, .6];
	minmax_x = [-2.5,5] + margin;
    minmax_y = [-4.5,3] + margin;
	xlim(minmax_x);
	ylim(minmax_y);
	%xlabel('i_x', 'FontSize',FontSize);
	%ylabel('i_y', 'FontSize',FontSize);
	set(gca,'XTick',[]);
	set(gca,'YTick',[]);
	
	set(gca, 'TickDir','out', 'FontSize',FontSize);
	set(gca, 'LineWidth',2);

	% diagonal line accross
	plot(minmax_x,minmax_y,'-k', 'LineWidth',4);
end
function DrawColDots_SpecialMerged_v2(data_C, offset, minmax_C, maxC)
	global GL
	
	% draw color dots
	function MS = DotSize(msMin,msMax, q)
%		MS = msMin + msMax * sqrt(2*abs(q - 0.5));
        MS = msMin + msMax * (2*abs(q - 0.5))^(1/3);
	end

	nPt = size(GL.iPoints,1);
	
	colPos = [.8 0 0];
	colNeg = [0 0 .8];
	scaleC = minmax_C(2) / maxC;

	for iPt = 1:nPt
		bVal = isInSameHalf_v2(GL.iPoints(iPt,1:2)+offset, offset);
		if bVal	== 1
			q = (scaleC*data_C(iPt) - minmax_C(1)) ./ (minmax_C(2) - minmax_C(1));
			%iColor = max( 1, min(nC, round((nC-1)*q+1) ) );
			if data_C(iPt) > 0
				colDot = colPos;
			else
				colDot = colNeg;
			end

			marSize = DotSize(0,65, q);
			marSize = max(marSize, 1e-6);

			plot(GL.iPoints(iPt,1)+offset(1),GL.iPoints(iPt,2)+offset(2),'o', ...
				'MarkerSize',marSize, 'MarkerEdgeColor','none', ...
				'MarkerFaceColor',colDot);
		end
	end
end
function bVal = isInSameHalf_v2(iPoint, offset)
	% threshold line is: y = x + shift
    shift = -2;
	bVal = 0;
	if offset(2)-offset(1) < shift
        % Mn3+
		if iPoint(2) - iPoint(1) < shift
			bVal = 1;
		end
    else
        % Mn4+
		if iPoint(2) - iPoint(1) > shift
			bVal = 1;
		end
    end
end

























