% Entry point (Hit F5 to run)
%{
===============================================================================
DESIGNED BY:    Tsezar F. Seman
AFFILIATION:    NJIT University, Physics Department
MODIFIED ON:    04/26/2012
COPYRIGHT:      (c) Tsezar F. Seman. All rights reserved.
PURPOSE:        Plotting various RIXS data.
===============================================================================
%}
function run6_plot_rixs__PRB(N)
	clc; addpath('_functions_','_common_');
	if nargin < 1
		clear all;
		N = 16;		% must be divisible by 4
	end
	
	isSaveEPS = 1;
	%--------------------------------------------
	% GENERATE RIXS DATASET:
	CmdTitle(sprintf('LaSrMnO4 PLOTTING RIXS (EPS): N = %i', N));
	fprintf('## LOADING CALCULATED RIXS: ... \n');
	LoadCalcRixs(N);

	%--------------------------------------------
	% SPECIAL PLOTTING FOR EPS REPORT:
	
	t0 = GetVal_t0();
	suf1 = sprintf('-t%0.1f',t0);

% K-INTENSITY:
%{
	Plot_kIntensityHalf__EPS();
	if isSaveEPS
		fig2eps(gcf,sprintf('k-map-half%s',suf1), 0);
	end
return;
%}
%{
	Plot_kIntensityFull__EPS();
	if isSaveEPS
		fig2eps(gcf,sprintf('k-map-full%s',suf1), 0);
	end
return;
%}

% V-SHAPE:
%{
	Plot_VShape__EPS(suf1,suf2);
	if isSaveEPS
		fig2eps(gcf,sprintf('v-shape%s',suf1));
	end
return;
%}
%{
	kNodes = [0,0;  pi,pi;  pi,0;  0,0;  0,pi;  pi,pi];  kMask = [1,2,2,2,2,1];
	kVals = CollectPathPoints(N,kNodes,kMask);
	Plot_VShapePath__EPS(kVals,suf1);
	if isSaveEPS
		fig2eps(gcf,sprintf('k-line-path%s',suf1), 0);	% eps base: 0-vector, 1-image
	end
%return;
%}

% CONTOUR:
%{
	kNodes = [0,0;  pi,pi];  kMask = [1,1];
	kVals = CollectPathPoints(N,kNodes,kMask);
	Plot_Contour1__EPS(kVals);
	if isSaveEPS
		fig2eps(gcf,sprintf('contour%s',suf1), 0);	% eps base: 0-vector, 1-image
	end
return;
%}
%{-
	kNodes = [0,0;  pi,pi;  pi,0;  0,0;  0,pi;  pi,pi];  kMask = [1,2,2,2,2,1];
	kVals = CollectPathPoints(N,kNodes,kMask);
	Plot_ContourPath__EPS(kVals);
	if isSaveEPS
		fig2eps(gcf,sprintf('contour-path%s',suf1), 1);	% eps base: 0-vector, 1-image
	end
%return;
%}

%{
	Plot_EHDistrib__EPS();	% E-H Distribution
	if isSaveEPS
		fig2eps(gcf,sprintf('eh-distrib%s',suf1), 0);	% eps base: 0-vector, 1-image
	end
%}
end
%==========================================================
% LINE/POINT PLOTTING HELPERS:
function index = KPtsToIndex(kPts)
	global GL
	
	del = 1e-10;
	index = zeros(size(kPts,1),1);
	for i = 1:size(GL.kPoints,1)
		k = GL.kPoints(i,:);
		tmp = kPts;
		tmp(:,1) = tmp(:,1) - k(1);
		tmp(:,2) = tmp(:,2) - k(2);
		index(sum(abs(tmp),2) < del, 1) = i;
	end
end
function index = KPtsToIndexExt(kPts)
	global GL
	
	del = 1e-10;
	index = zeros(size(kPts,1),1);
	for i = 1:size(GL.kPointsExt,1)
		k = GL.kPointsExt(i,:);
		tmp = kPts;
		tmp(:,1) = tmp(:,1) - k(1);
		tmp(:,2) = tmp(:,2) - k(2);
		index(sum(abs(tmp),2) < del, 1) = GL.kIndexExt(i,1);
	end
end

function kVals = CollectPathPoints(N,kNodes,kMask)
	nNodes = size(kNodes,1);
	dsq = 2*pi/N;
	t = 0;	% starting parametric value
	kVals = [];
	for i = 1:nNodes-1
		k1 = kNodes(i,:);
		k2 = kNodes(i+1,:);	
		nx = abs(k2(1)-k1(1)) / dsq;  dx = sign((k2(1)-k1(1))) * dsq;
		if nx == 0; dx = 0; end;
		ny = abs(k2(2)-k1(2)) / dsq;  dy = sign((k2(2)-k1(2))) * dsq;
		if ny == 0; dy = 0; end;
		Lsq = sqrt( dx^2 + dy^2 );
		nPts = max(nx,ny);
		kPath = zeros(nPts,4);
		kPath(1,:) = [t, kMask(i), k1(1), k1(2)];
		for j = 2:nPts
			t = t + Lsq;
			kx = kPath(j-1,3)+dx;
			ky = kPath(j-1,4)+dy;
			kPath(j,:) = [t, 0, kx, ky];
		end
		t = t + Lsq;
		if i == nNodes-1;
			kPath = [kPath;   t, kMask(i+1), k2(1), k2(2)];
		end
		kVals = [kVals; kPath];
	end
end
%==========================================================
% SAVING/LOADING:
function LoadCalcRixs(N)
	% ACCESS to overwrite
	global GL
	
	path = sprintf('_N%02i_data_/_RIXS_',N);
	load(sprintf('%s/N%02i_CalcRixs.mat',path,N));
	
	GL.figId = 30;
	GL.figPref = sprintf('N = %d',GL.N);
end

function t0 = GetVal_t0()
	global GL
	
	t0 = GL.C.t0;
end
%==========================================================

%==========================================================
% SPECIAL EPS ROUTINES:
function Plot_kIntensityHalf__EPS()
	global GL
	
	rixs_sum = sum(GL.RIXS_SUM, 2);
	rixs_sum_ext = rixs_sum(GL.kIndexExt,1);	
	data = [GL.kPoints, rixs_sum;  GL.kPointsExt, rixs_sum_ext ];
	szTitle = sprintf('%s: \\Sigma I_{RIXS} in k-Space', GL.figPref);
	
	[~,scale,exponent] = NiceMax(max(data(:,3)));
	data(:,3) = scale * data(:,3);
	minmax_I = [min(data(:,3)), max(data(:,3))];
	fprintf('Real min/max:\n[%.8f, %.8f]\n',min(data(:,3)),max(data(:,3)));
	
	GL.figId = FigId(GL.figId,szTitle);
	
	function SqPatch(x,y,dsq,col)
		arX = [x-dsq,x+dsq,x+dsq,x-dsq];
		arY = [y-dsq,y-dsq,y+dsq,y+dsq];
		fill(arX,arY,col, 'Linestyle','none');
	end	
	dsq = pi / GL.N;	% half-width of the square color patch
	
	nK = size(data,1);
	nC = 128;
	cmap = colormap( jet(nC) );
	hold on;
	for iPt = 1:nK
		q = (data(iPt,3) - minmax_I(1)) ./ (minmax_I(2) - minmax_I(1));
		% color
		iColor = max( 1, min(nC, round( (nC - 1) * q + 1 )) );
		SqPatch(data(iPt,1),data(iPt,2), dsq, cmap(iColor,:));
	end
	
	% draw diamond frame
	frameX = [0 pi 0]/2; frameY = [-pi 0 pi]/2;
	plot(frameX, frameY, '--','Color',[1,1,1], 'LineWidth',2);
	% re-draw black outline
	frameX = [0 pi pi 0 0]; frameY = [-pi -pi pi pi -pi];
	plot(frameX, frameY, '-','Color',[0,0,0], 'LineWidth',2);
	
	hold off;
	
	FontSize = 25;
	hcb = colorbar;
	caxis(minmax_I);
	axis('equal');
	xlim([  0,pi]);
	ylim([-pi,pi]);
	box('on');	
	% axis adjustments
	q = linspace(-pi,pi,9);
	set(gca, 'XTick',q, 'XTickLabel','');
	set(gca, 'YTick',q, 'YTickLabel','');
	set(gca, 'TickDir','out', 'FontSize',FontSize);
	set(gca, 'LineWidth',2);
	% colorbar adjustments
	set(hcb, 'LineWidth',2);

	% bottom text
	shft = -pi-0.35;
	FigText( 0,		shft,		'0', FontSize);
	FigText( pi/2,	shft,		'\pi/2', FontSize);
	FigText( pi,	shft,		'\pi', FontSize);	
	FigText( pi/2,	shft-0.5,	'\Delta{q_x}', FontSize);
	% side left text
	shft = -0.2;
	FigText(shft,	-pi,		'-\pi', FontSize, 0, 'right');
	FigText(shft,	-pi/2,		'-\pi/2', FontSize, 0, 'right');
	FigText(shft,	0,			'0', FontSize, 0, 'right');
	FigText(shft,	pi/2,		'\pi/2', FontSize, 0, 'right');
	FigText(shft,	pi,			'\pi', FontSize, 0, 'right');
	FigText(shft-0.7,	0,		'\Delta{q_y}', FontSize, 90);
	% side right text
	FigText(pi+1.5, 0, sprintf('Integrated Intensity (x10^{%d})',exponent), FontSize,90);
		
	camva(1.2*camva)
end
function Plot_kIntensityFull__EPS()
	global GL
	
	rixs_sum = sum(GL.RIXS_SUM, 2);
	rixs_sum_ext = rixs_sum(GL.kIndexExt,1);	
	data = [GL.kPoints, rixs_sum;  GL.kPointsExt, rixs_sum_ext ];
	szTitle = sprintf('%s: \\Sigma I_{RIXS} in k-Space', GL.figPref);
	
	[~,scale,exponent] = NiceMax(max(data(:,3)));
	data(:,3) = scale * data(:,3);
	minmax_I = [min(data(:,3)), max(data(:,3))];
	fprintf('Real min/max:\n[%.8f, %.8f]\n',min(data(:,3)),max(data(:,3)));
	
	GL.figId = FigId(GL.figId,szTitle);
	
	function SqPatch(x,y,dsq,col)
		arX = [x-dsq,x+dsq,x+dsq,x-dsq];
		arY = [y-dsq,y-dsq,y+dsq,y+dsq];
		fill(arX,arY,col, 'Linestyle','none');
	end	
	dsq = pi / GL.N;	% half-width of the square color patch
	

	nK = size(data,1);
	nC = 128;
	cmap = colormap( jet(nC) );
	hold on;
	for iPt = 1:nK
		q = (data(iPt,3) - minmax_I(1)) ./ (minmax_I(2) - minmax_I(1));
		% color
		iColor = max( 1, min(nC, round( (nC - 1) * q + 1 )) );
		SqPatch(data(iPt,1),data(iPt,2), dsq, cmap(iColor,:));
	end	

	% draw diamond frame
	frameX = [pi 0 -pi 0 pi]/2; frameY = [0 pi 0 -pi 0]/2;
	plot(frameX, frameY, '--','Color',[1,1,1], 'LineWidth',2);
	% re-draw black outline
	frameX = [-pi pi pi -pi -pi]; frameY = [-pi -pi pi pi -pi];
	plot(frameX, frameY, '-','Color',[0,0,0], 'LineWidth',2);
	
	hold off;
	
	FontSize = 25;
	hcb = colorbar;
	caxis(minmax_I);
	axis('equal');
	xlim([-pi,pi]);
	ylim([-pi,pi]);
	box('on');	
	% axis adjustments
	q = linspace(-pi,pi,9);
	set(gca, 'XTick',q, 'XTickLabel','');
	set(gca, 'YTick',q, 'YTickLabel','');
	set(gca, 'TickDir','out', 'FontSize',FontSize);
	set(gca, 'LineWidth',2);
	% colorbar adjustments
	set(hcb, 'LineWidth',2);

	% bottom text
	shft = -pi-0.35;
	FigText( -pi,	shft,		'-\pi', FontSize);
	FigText( -pi/2,	shft,		'-\pi/2', FontSize);
	FigText( 0,		shft,		'0', FontSize);
	FigText( pi/2,	shft,		'\pi/2', FontSize);
	FigText( pi,	shft,		'\pi', FontSize);
	FigText( 0,	shft-0.5,		'\Delta{q_x}', FontSize);
	% side left text
	shft = -pi-0.2;
	FigText(shft,	-pi,		'-\pi', FontSize, 0, 'right');
	FigText(shft,	-pi/2,		'-\pi/2', FontSize, 0, 'right');
	FigText(shft,	0,			'0', FontSize, 0, 'right');
	FigText(shft,	pi/2,		'\pi/2', FontSize, 0, 'right');
	FigText(shft,	pi,			'\pi', FontSize, 0, 'right');
	FigText(shft-0.7,	0,		'\Delta{q_y}', FontSize, 90);
	% side right text
	FigText(pi+1.5, 0, sprintf('Integrated Intensity (x10^{%d})',exponent), FontSize,90);
		
	camva(1.2*camva)
end


function Plot_VShape__EPS(suf1)
	global GL
	
	rixs_sum = sum(GL.RIXS_SUM, 2);
	rixs_sum_ext = rixs_sum(GL.kIndexExt,1);	
	data = [GL.kPoints,rixs_sum; GL.kPointsExt,rixs_sum_ext ];
	szTitle = sprintf('%s: \\Sigma I_{RIXS} along lines in k-Space', GL.figPref);
	
	FontSize = 25;
	
	GL.figId = FigId(GL.figId,szTitle);
	%I_lim = [0,max(data(:,3))];
	I_lim = [0,10];
	data = sortrows(data, [2, 1]);
		
	hold on;
	% diagonal kx = ky:
	d = data(data(:,1) - data(:,2) == 0, :);
	x = sign(d(:,1)) .* sqrt(d(:,1).^2 + d(:,2).^2);
	yScale = 1/min(d(:,3));
	y = yScale * d(:,3);
%	plot(x,y, '-k',  'LineWidth',3);	%, 'Marker','o','MarkerSize',12,'MarkerFaceColor','k'
	
	% smooth spline	
	sh = 2*sqrt(2)*pi; nx = length(x);
	xxSp = linspace(x(1),x(length(x)), 257);
	yySp = spline(x,y,xxSp);
	plot(xxSp,yySp, '-k',  'LineWidth',3);
	
fprintf('R = %.4f\n',max(yySp));

	
	ylabel(sprintf('Integrated Intensity'), 'FontSize',FontSize);
	pi2 = pi*sqrt(2);
	xlim([-1,1]*pi2);
	ylim(I_lim);
	
	box('on');
	set(gca, 'FontSize',FontSize);
	set(gca, 'XTick',[-pi2,-pi2/2,0,pi2/2,pi2], 'XTickLabel','');
	set(gca, 'LineWidth',2);
	axis('square');
	
	% bottom text
	shft = abs(I_lim(2)-I_lim(1)) / 30;
	FigText(-pi2,-shft,		'(-\pi,-\pi)', FontSize);
	FigText(-pi2/2,-shft,	'(-\pi/2,-\pi/2)', FontSize);
	FigText(   0,-shft,		'0', FontSize);
	FigText( pi2/2,-shft,	'(\pi/2,\pi/2)', FontSize);
	FigText( pi2,-shft,		'(\pi,\pi)', FontSize);
	
	FigText(  0, -2.5*shft,	'Momentum Change', FontSize);
	
	hold off;
	
	camva(1.2*camva)

%{-
	% extract SPLINE data
	MakeDir('_EPS_');	
	dataSmooth = [xxSp; yySp]';
	dataSmooth = dataSmooth(dataSmooth(:,1)>=0, :);
	dataSmooth(:,2) = dataSmooth(:,2) / yScale;
	file = sprintf('_EPS_/k-line-data%s.txt',suf1);
%	file = sprintf('_EPS_/k-line-data%s-ch%d.txt',suf1,GL.CH);
	save(file,'dataSmooth','-ascii','-double');
	fprintf('    * File [%s] have been generated.\n',file);
%}
end
function Plot_VShapePath__EPS(kVals,suf1)
	global GL
	
	% k-point indexes to use in search for RIXS values
	kInd = KPtsToIndex(kVals(:,3:4)) + KPtsToIndexExt(kVals(:,3:4));
	rixs_sum = sum(GL.RIXS_SUM, 2);
	Irixs = rixs_sum(kInd);	
	
	FontSize = 25;
	
	GL.figId = FigId(GL.figId,'V-Shape Path');
	minmax_q = [kVals(1,1), kVals(size(kVals,1),1)];
	minmax_I = [0,max(Irixs)];
	
	hold on;
	% plot data
	x = kVals(:,1); y = Irixs;
	xxSp = linspace(x(1),x(length(x)), 300);
	yySp = spline(x,y,xxSp);
	plot(xxSp,yySp, '-k',  'LineWidth',3);
	%plot(kVals(:,1),Irixs, '*-b');
	
	% set nice max y-value
	exp_y = floor(log10(max(yySp)));
	minmax_I(2) = 10^exp_y * ceil( max(yySp) / 10^exp_y );
	
	
	% vertical lines
	kValsVert = kVals(kVals(:,2) == 2, 1);
	for i=1:size(kValsVert,1)
		plot(kValsVert(i,1)*[1,1], minmax_I, '--', 'Color',[.6,.6,.6], 'LineWidth',1.5);
	end
	
	kMarks = kVals(kVals(:,2) > 0, :);
	set(gca, 'XTick',kMarks(:,1), 'XTickLabel','');
	%set(gca, 'YTick',0:2:8);
	set(gca, 'LineWidth',2);
	set(gca, 'FontSize',FontSize);
	axis('square');
	box('on');
	xlim(minmax_q);
	ylim(minmax_I);
	ylabel(sprintf('Integrated Intensity'), 'FontSize',FontSize);
	
	% bottom text
	shft = abs(minmax_I(2)-minmax_I(1)) / 12;
	for i=1:size(kMarks,1)
		str = ['(', Num2Latex(kMarks(i,3),1), ',', Num2Latex(kMarks(i,4),1), ')'];
		FigText(kMarks(i,1), -shft, str, FontSize);
	end	
	% bottom label
	FigText((max(kMarks(:,1))-min(kMarks(:,1)))/2, -2.5*shft, 'Momentum Change', FontSize);
	hold off;
	
	set(gca,'PlotBoxAspectRatio',[1 .6 1])
	
	camva(1.2*camva)
	
%{-
	% extract SPLINE data
	MakeDir('_EPS_');	
	dataSmooth = [xxSp; yySp]';
	file = sprintf('_EPS_/k-line-path-data%s.txt',suf1);
	save(file,'dataSmooth','-ascii','-double');
	fprintf('    * File [%s] have been generated.\n',file);
	
	save('_EPS_/kVals.mat','kVals')
%}
end

function Plot_Contour1__EPS(kVals,gammaW)
	global GL
	
	gammaW = 0.6;
	FontSize = 25;
	Ny = 400;
	Nx = 200;
	
	LorentzianW = @(ww,w0) ( (gammaW./pi) ./ ((ww-w0).^2 + gammaW.^2) );
	
	nk = size(kVals,1);	
	minmax_q = [kVals(1,1), kVals(nk,1)];
	
	%minmax_w = [floor( min(GL.RIXS(:,4)) ), ceil( max(GL.RIXS(:,4)) )];
	%minmax_w = [0, ceil( max(GL.RIXS(:,4)) )];
	minmax_w = [0, 5];
	xCont = linspace(minmax_q(1), minmax_q(2), Nx);
	yCont = linspace(minmax_w(1), minmax_w(2), Ny);

	% k-point indexes to use in search for RIXS values
	kInd = KPtsToIndex(kVals(:,3:4)) + KPtsToIndexExt(kVals(:,3:4));
	
	% collect all w-sets as smooth Lorentzians
	w_set = zeros(Ny, nk);
	for ik = 1:nk
		% collect all intensities and energies for a given k-point
		IWrixs = GL.RIXS(GL.RIXS(:,8) == kInd(ik), 3:4);
		I_tmp = zeros(size(yCont));
		for iw = 1:size(IWrixs,1)
			I_tmp = I_tmp + IWrixs(iw,1) .* LorentzianW(yCont,IWrixs(iw,2));
		end
		w_set(:,ik) = I_tmp';
	end
	
	% interpolate horizontally
	[qq,ww] = meshgrid(xCont, yCont);
	zz = zeros(size(qq));
	q_param = kVals(:,1)';
	for iw = 1:Ny
		I_tmp = w_set(iw,:);
		zz(iw,:) = spline(q_param,I_tmp, xCont);
	end
	
[c1,i1] = max(zz,[],2);
[c2,i2] = max(c1);

Imax = c2;
ix = i1(i2);
iy = i2;
qVal = qq(iy,ix);
wVal = ww(iy,ix);

fprintf('Max E = %.4f\n',wVal);
	
	
	maxZ = max(max(zz));
	zz = zz ./ maxZ;
	fprintf('Max Irixs = %.2e\n',maxZ);
	
	% plot contour map
	szTitle = sprintf('%s: Integrated I_{ RIXS} Contribution',GL.figPref);
	GL.figId = FigId(GL.figId,szTitle);
	hold on;
	pcolor(qq,ww,zz);
	caxis([0, 1]);
	axis('tight');	%'equal'
	colormap(hot(128));
	shading('flat');
	hcb = colorbar;
	xlim(minmax_q);
	ylim(minmax_w);
	
plot(qVal,wVal,'.m')

	% axis matters
	ylabel('Energy (eV)', 'FontSize',FontSize);
	set(gca, 'TickDir','out', 'FontSize',FontSize);
	
	% colorbar adjustments
	set(hcb, 'LineWidth',2);
	
	pi2 = pi*sqrt(2);
	set(gca, 'XTick',[0,pi2/2,pi2], 'XTickLabel','');
	set(gca, 'YTick',0:2:8);
	set(gca, 'LineWidth',2);
	%axis('square');
%axis('off');
	box('on')
	set(gca,'PlotBoxAspectRatio',[.3 1 1])
	
	% bottom text
	shft = abs(minmax_w(2)-minmax_w(1)) / 20;
	FigText(   0,-shft,		'(0,0)', FontSize, 0,'left');
%	FigText( pi2/2,-shft,	'(\pi/2,\pi/2)', FontSize);
	FigText( pi2,-shft,		'(\pi,\pi)', FontSize, 0,'right');
%	FigText(  0,-2.5*shft,	'Momentum Change', FontSize);
	% side right text
	FigText(minmax_q(2)+2.2, (minmax_w(2)-minmax_w(1))/2, 'Normalized Intensity', FontSize,90);
	
	hold off;

	camva(1.2*camva)
end
function Plot_ContourPath__EPS(kVals)
	global GL
	
	gammaW = 0.6;
	FontSize = 15;
	Ny = 200;
	Nx = 200;
	
	LorentzianW = @(ww,w0) ( (gammaW./pi) ./ ((ww-w0).^2 + gammaW.^2) );
	
	nk = size(kVals,1);	
	minmax_q = [kVals(1,1), kVals(nk,1)];

	%minmax_w = [floor( min(GL.RIXS(:,4)) ), ceil( max(GL.RIXS(:,4)) )];
	%minmax_w = [0, ceil( max(GL.RIXS(:,4)) )];
	minmax_w = [0, 5];
	xCont = linspace(minmax_q(1), minmax_q(2), Nx);
	yCont = linspace(minmax_w(1), minmax_w(2), Ny);

	% k-point indexes to use in search for RIXS values
	kInd = KPtsToIndex(kVals(:,3:4)) + KPtsToIndexExt(kVals(:,3:4));
	
	% collect all w-sets as smooth Lorentzians
	w_set = zeros(Ny, nk);
	for ik = 1:nk
		% collect all intensities and energies for a given k-point
		IWrixs = GL.RIXS(GL.RIXS(:,8) == kInd(ik), 3:4);
		I_tmp = zeros(size(yCont));
		for iw = 1:size(IWrixs,1)
			I_tmp = I_tmp + IWrixs(iw,1) .* LorentzianW(yCont,IWrixs(iw,2));
		end
		w_set(:,ik) = I_tmp';
	end
	
	% interpolate horizontally
	[qq,ww] = meshgrid(xCont, yCont);
	zz = zeros(size(qq));
	q_param = kVals(:,1)';
	for iw = 1:Ny
		I_tmp = w_set(iw,:);
		zz(iw,:) = spline(q_param,I_tmp, xCont);
	end
	maxZ = max(max(zz));
	minZ = min(min(zz));
	zz = (zz - minZ) ./ (maxZ - minZ);
%	[nice_max,scale,exponent] = NiceMax(maxZ);
%	zz = zz * scale;

	% plot contour map
	szTitle = sprintf('%s: Integrated I_{ RIXS} Contribution',GL.figPref);
	GL.figId = FigId(GL.figId,szTitle);
	hold on;
	pcolor(qq,ww,zz);
	caxis([0, 1]);
	axis('tight');	%'equal'
	colormap(hot(128));
	shading('flat');
	hcb = colorbar;
	xlim(minmax_q);
	ylim(minmax_w);
	
	
	% vertical white lines
	kValsVert = kVals(kVals(:,2) == 2, 1);
	for i=1:size(kValsVert,1)
		plot(kValsVert(i,1)*[1,1], minmax_w, '--w', 'LineWidth',1.5);
	end

	% axis matters
	ylabel('Energy (eV)', 'FontSize',FontSize);
	set(gca, 'TickDir','out', 'FontSize',FontSize);
	
	% colorbar adjustments
	set(hcb, 'LineWidth',2);
	
	kMarks = kVals(kVals(:,2) > 0, :);
	set(gca, 'XTick',kMarks(:,1), 'XTickLabel','');
	set(gca, 'YTick',0:8, 'YTickLabel',{'0';'';'2';'';'4';'';'6';'';'8'});
	set(gca, 'LineWidth',2);
	axis('square');
%axis('off');
	box('on')
%	set(gca,'PlotBoxAspectRatio',[.4 1 1])
	set(gca,'PlotBoxAspectRatio',[1 0.6 1])
	
	% bottom text
	shft = abs(minmax_w(2)-minmax_w(1)) / 30;
	for i=1:size(kMarks,1)
		str = ['(', Num2Latex(kMarks(i,3),1), ',', Num2Latex(kMarks(i,4),1), ')'];
		FigText(kMarks(i,1), -shft, str, FontSize);
	end	
	% bottom label
	FigText((max(kMarks(:,1))-min(kMarks(:,1)))/2, -2.5*shft, 'Momentum Change', FontSize);
	% side right text
%	FigText(minmax_q(2)+3.0, (minmax_w(2)-minmax_w(1))/2, ...
%		sprintf('RIXS Intensity (x10^{ %d})',exponent), FontSize,90);
	FigText(minmax_q(2)+3.0, (minmax_w(2)-minmax_w(1))/2, ...
		sprintf('Normalized RIXS Intensity'), FontSize,90);
	
	hold off;

	camva(1.2*camva)
end

function Plot_EHDistrib__EPS()
	global GL
	
	gamma = 0.05;
	spin = 1;	% 1-up or 2-down
	
	rixs = GL.RIXS(GL.RIXS(:,7)==spin, 1:4);
	energ = GL.MAP_CH0(:,1,spin);
	
	% COLLECT DATA
	nE = size(energ, 1);
	nF = round(nE / 8);	% Fermi threshhold
	data = zeros(nE,2);
	spoff = [1, 0];
	for iE = 1:nE
		E = energ(iE);
		if iE <= nF
			I = sum( rixs(rixs(:,1) == (2*iE-spoff(spin)), 3) );
			data(iE,:) = [I, E];
		else
			I = sum( rixs(rixs(:,2) == (2*iE-spoff(spin)), 3) );
			data(iE,:) = [I, E];
		end
	end
	minmaxI = [0, 1.1*max(data(:,1))];
	minmaxI(2) = max(2e-3, minmaxI(2));
	%minmaxE = [floor(min(data(:,2))), ceil(max(data(:,2)))];
	minmaxE = [-1,9];
	
	%[sum(data(1:nF,1)), sum(data(nF+1:nE,1))]
	
	% DISPLAY PLOT
	szTitle = sprintf('N=%i: Electron and Hole Distribution',GL.N);
	GL.figId = FigId(GL.figId,szTitle);
	hold on;
	for iE = 1:nE
		plot([0,data(iE,1)], [data(iE,2),data(iE,2)], '-b');
	end
	plot(data(1:nF,1), data(1:nF,2), 'ob', ...
		'MarkerSize',10, 'MarkerFaceColor',[1 .7 0]);
	plot(data(nF+1:nE,1), data(nF+1:nE,2), 'ob', ...
		'MarkerSize',10, 'MarkerFaceColor',[.8 .5 .9]);
	% Fermi line
%	yF = (data(nF,2)+data(nF+1,2))/2;
%	plot(minmaxI, [yF,yF], '--', 'Color',[.2,.8,.2]);
	
	% Lorentzian:
	pdfCL = @(y,y0) (gamma./pi) ./ ((y-y0).^2 + gamma.^2);
	yCL = linspace(minmaxE(1),minmaxE(2),400);
	xCL = 0*yCL;
	for iE=1:nE
		xCL = xCL + data(iE,1) .* pdfCL(yCL, data(iE,2));
	end
	sigma = minmaxI(2)/max(xCL);
	xCL = xCL * sigma;	
	plot(xCL,yCL, '-r', 'LineWidth',3);
%	text(0.98*minmaxI(2),0.98*minmaxE(2),sprintf('\\gamma = %.2f',gamma),...
%		'Color','r', 'HorizontalAlignment','right', 'VerticalAlignment','top');
	
	hold off;
	
	FontSize = 25;
	box on;
	set(gca,'YGrid','on')
	xlim(minmaxI);
	ylim(minmaxE);
%	title(szTitle);
	xlabel('Intensity Contribution', 'FontSize',FontSize);
	ylabel('Energy (eV)', 'FontSize',FontSize);
	axis('square');
	
	set(gca, 'FontSize',FontSize, 'LineWidth',2);
end
%==========================================================

%{
	% 2D interpolation
	dd = sortrows(data,[2,1]);	
	x = unique(data(:,1));
	y = unique(data(:,2));
	[xx,yy] = meshgrid(x,y);
	zz = reshape(dd(:,3),length(y),length(y))';

	[xxi,yyi] = meshgrid( linspace(-pi,pi,200) );
	%zzi = interp2(xx,yy,zz,xxi,yyi,'bicubic');
	zzi = interp2(xx,yy,zz,xxi,yyi,'nearest');
	
	% color contour plot
	hold on;
	pcolor(xxi,yyi,zzi);
	shading('flat');
	colormap(jet(128));
%}

